window.Gleam.initSearch([{"doc":"sprocket","title":"sprocket","content":"# Sprocket\nA library for building real-time server UI components and live views in [Gleam ✨](https://gleam.run/)\n\n[![Package Version](https://img.shields.io/hexpm/v/sprocket)](https://hex.pm/packages/sprocket)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sprocket/)\n\n[Demo Documentation](https://sprocket.live)\n\nHeavily inspired by [Phoenix LiveView](https://github.com/phoenixframework/phoenix_live_view) and\n[React](https://github.com/facebook/react). The name &quot;sprocket&quot; is loosely derived from the metaphor\nof a bicycle&#39;s sprocket, cassette and chain.\n\nAn initial static view is rendered as HTML on the &quot;first paint&quot; which then establishes a connection to the server over a\nWebSocket to facilitate sending browser events and receiving view update diffs. These updates are\npatched into a client-side in-memory representation of the DOM and efficiently rendered to the\nbrowser DOM. Declarative views are built using functional components that accept props and re-render\neach time those props change. Contextual hooks are used to manage state and effects, e.g.\n`state`, `reducer` and `effect`.\n\nTyped component interfaces snap together and are used to create higher-level views. Data flow is\n&quot;uni-directional&quot; in that **State** always flows down into components as props and **Events**\nbubble up through event handler functions (which are also passed in as props, e.g.\n`on_some_event(&quot;Something happened&quot;)`). \n\n## Key Features\n\n- Real-time server-side UI component library\n- Renders initial HTML and efficiently patches update diffs using a persistent WebSocket connection\n- Declarative and composable functional components that re-render when props or state change\n- Strongly-typed language means minimal runtime bugs and better peace of mind\n- Lightweight OTP processes are used for efficient and scalable runtimes\n\n## Example\n\n### Clock Component\n```gleam\ntype Model {\n  Model(time: Int, timezone: String)\n}\n\ntype Msg {\n  NoOp\n  UpdateTime(Int)\n}\n\nfn update(model: Model, msg: Msg) -&gt; Model {\n  case msg {\n    NoOp -&gt; model\n    UpdateTime(time) -&gt; {\n      Model(..model, time: time)\n    }\n  }\n}\n\nfn initial() -&gt; Model {\n  Model(time: erlang.system_time(erlang.Second), timezone: &quot;UTC&quot;)\n}\n\npub type ClockProps {\n  ClockProps(label: Option(String))\n}\n\npub fn clock(ctx: Context, props) {\n  let ClockProps(label) = props\n\n  // Define a reducer to handle events and update the state\n  use ctx, Model(time: time, ..), dispatch &lt;- reducer(\n    ctx,\n    initial(),\n    update,\n  )\n\n  // Example effect that runs whenever the `time` variable changes and has a cleanup function\n  use ctx &lt;- effect(\n    ctx,\n    fn() {\n      let cancel =\n        interval(\n          1000,\n          fn() { dispatch(UpdateTime(erlang.system_time(erlang.Second))) },\n        )\n\n      Some(fn() { cancel() })\n    },\n    WithDeps([dep(time)]),\n  )\n\n  let current_time = int.to_string(time)\n\n  render(\n    ctx,\n    case label {\n      Some(label) -&gt; fragment([span([], [text(label)]), span([], [text(current_time)])])\n      None -&gt; text(current_time)\n    },\n  )\n}\n```\n\n### Parent view\n```gleam\npub type ExampleViewProps {\n  ExampleViewProps\n}\n\npub fn example_view(ctx: Context, _props: ExampleViewProps) {\n  render(\n    ctx,\n    html(\n      [lang(&quot;en&quot;)],\n      [\n        head([], [link([rel(&quot;stylesheet&quot;), href(&quot;/app.css&quot;)])]),\n        body(\n          [class(&quot;bg-white dark:bg-gray-900 dark:text-white p-4&quot;)],\n          [\n            component(\n              clock,\n              ClockProps(label: Some(&quot;The current time is: &quot;)),\n            ),\n          ],\n        ),\n      ],\n    ),\n  )\n}\n\n```\n\n## Getting Started\n\nTo get started with Sprocket, follow the instructions below:\n\n1. Clone the Sprocket starter repository:\n```sh\ngit clone https://github.com/bitbldr/sprocket_starter.git\n```\n\n1. Install the required dependencies:\n```sh\ngleam deps download\nyarn\n```\n\n1. Start the development server:\n```sh\nyarn run watch\n```\n\n1. Open your web browser and visit [http://localhost:3000](http://localhost:3000) to see the starter app.\n\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add sprocket\n```\n\nFor getting started with Sprocket, refer to the [Official Docs](https://sprocket.live).\nHere you will find detailed examples and tutorials. These docs are\nbuild with sprocket, which also make them an excellent reference implementation [github.com/bitbldr/sprocket_docs](https://github.com/bitbldr/sprocket_docs).\n\n\n## API Documentation\n\nAPI documentation can be found at &lt;https://hexdocs.pm/sprocket&gt;.\n\n\n## Roadmap\n\nSprocket is still in its early stages and has a roadmap for future development. Here are some of the planned improvements:\n\n- [x] Build out full set of base HTML functions for components\n- [x] ~~Explore other http and websocket server options~~ Core library is now web server agnostic\n- [ ] Add support for additional event types to handle various user interactions\n- [x] Expand the available hooks to enable more flexible component behavior\n- [ ] Convert client TypeScript to gleam\n- [ ] Improve unit test coverage to ensure code quality and reliability\n- [x] Provide extensive documentation of modules and simplify API\n- [ ] Optimize performance to enhance responsiveness and scalability\n- [ ] Add support for web-based client components\n- [ ] Investigate extending to support more than just web views, such as native desktop, iOS, and Android applications.\n\n## Contributing\n\nContributions to Sprocket are welcome and encouraged! If you would like to contribute, please follow\nthe guidelines outlined in the\n[CONTRIBUTING.md](https://github.com/bitbldr/sprocket/blob/master/CONTRIBUTING.md) file.\n\n## License\n\nSprocket is released under the [MIT License](https://github.com/bitbldr/sprocket/blob/master/LICENSE.md).\n","url":"index.html"},{"doc":"sprocket/context","title":"AbstractFunctionalComponent","content":"pub type AbstractFunctionalComponent =\n  fn(Context, Dynamic) -&gt; #(Context, Element)\n\n\nSynonyms:\nsprocket/context.AbstractFunctionalComponent\nsprocket/context AbstractFunctionalComponent","url":"sprocket/context.html#AbstractFunctionalComponent"},{"doc":"sprocket/context","title":"Attribute","content":"pub type Attribute {\n  Attribute(name: String, value: Dynamic)\n  Event(name: String, handler: IdentifiableHandler)\n  ClientHook(id: Unique, name: String)\n}\n\nAttribute(name: String, value: Dynamic)\n\n\nEvent(name: String, handler: IdentifiableHandler)\n\n\nClientHook(id: Unique, name: String)\n\n\nSynonyms:\nsprocket/context.Attribute\nsprocket/context Attribute","url":"sprocket/context.html#Attribute"},{"doc":"sprocket/context","title":"CallbackParam","content":"pub type CallbackParam {\n  CallbackString(value: String)\n}\n\nCallbackString(value: String)\n\n\nSynonyms:\nsprocket/context.CallbackParam\nsprocket/context CallbackParam","url":"sprocket/context.html#CallbackParam"},{"doc":"sprocket/context","title":"CallbackResult","content":"pub type CallbackResult {\n  CallbackResult(deps: Option(HookDependencies))\n}\n\nCallbackResult(deps: Option(HookDependencies))\n\n\nSynonyms:\nsprocket/context.CallbackResult\nsprocket/context CallbackResult","url":"sprocket/context.html#CallbackResult"},{"doc":"sprocket/context","title":"ClientDispatcher","content":"pub type ClientDispatcher =\n  fn(String, Option(String)) -&gt; Result(Nil, Nil)\n\n\nSynonyms:\nsprocket/context.ClientDispatcher\nsprocket/context ClientDispatcher","url":"sprocket/context.html#ClientDispatcher"},{"doc":"sprocket/context","title":"ClientEventHandler","content":"pub type ClientEventHandler =\n  fn(String, Option(Dynamic), ClientDispatcher) -&gt; Nil\n\n\nSynonyms:\nsprocket/context.ClientEventHandler\nsprocket/context ClientEventHandler","url":"sprocket/context.html#ClientEventHandler"},{"doc":"sprocket/context","title":"Compared","content":"pub type Compared(a) {\n  Changed(changed: a)\n  Unchanged\n}\n\nChanged(changed: a)\n\n\nUnchanged\n\n\nSynonyms:\nsprocket/context.Compared\nsprocket/context Compared","url":"sprocket/context.html#Compared"},{"doc":"sprocket/context","title":"ComponentHooks","content":"pub type ComponentHooks =\n  OrderedMap(Int, Hook)\n\n\nSynonyms:\nsprocket/context.ComponentHooks\nsprocket/context ComponentHooks","url":"sprocket/context.html#ComponentHooks"},{"doc":"sprocket/context","title":"ComponentWip","content":"pub type ComponentWip {\n  ComponentWip(\n    hooks: ComponentHooks,\n    index: Int,\n    is_first_render: Bool,\n  )\n}\n\nComponentWip(\n  hooks: ComponentHooks,\n  index: Int,\n  is_first_render: Bool,\n)\n\n\nSynonyms:\nsprocket/context.ComponentWip\nsprocket/context ComponentWip","url":"sprocket/context.html#ComponentWip"},{"doc":"sprocket/context","title":"Context","content":"pub type Context {\n  Context(\n    view: Element,\n    wip: ComponentWip,\n    handlers: List(IdentifiableHandler),\n    render_update: fn() -&gt; Nil,\n    update_hook: fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil,\n    dispatch_event: fn(Unique, String, Option(String)) -&gt;\n      Result(Nil, Nil),\n    cuid_channel: Subject(cuid.Message),\n    providers: Dict(String, Dynamic),\n  )\n}\n\nContext(\n  view: Element,\n  wip: ComponentWip,\n  handlers: List(IdentifiableHandler),\n  render_update: fn() -&gt; Nil,\n  update_hook: fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil,\n  dispatch_event: fn(Unique, String, Option(String)) -&gt;\n    Result(Nil, Nil),\n  cuid_channel: Subject(cuid.Message),\n  providers: Dict(String, Dynamic),\n)\n\n\nSynonyms:\nsprocket/context.Context\nsprocket/context Context","url":"sprocket/context.html#Context"},{"doc":"sprocket/context","title":"Dispatcher","content":"pub type Dispatcher {\n  Dispatcher(\n    dispatch: fn(String, String, Option(String)) -&gt;\n      Result(Nil, Nil),\n  )\n}\n\nDispatcher(\n  dispatch: fn(String, String, Option(String)) -&gt;\n    Result(Nil, Nil),\n)\n\n\nSynonyms:\nsprocket/context.Dispatcher\nsprocket/context Dispatcher","url":"sprocket/context.html#Dispatcher"},{"doc":"sprocket/context","title":"EffectCleanup","content":"pub type EffectCleanup =\n  Option(fn() -&gt; Nil)\n\n\nSynonyms:\nsprocket/context.EffectCleanup\nsprocket/context EffectCleanup","url":"sprocket/context.html#EffectCleanup"},{"doc":"sprocket/context","title":"EffectResult","content":"pub type EffectResult {\n  EffectResult(\n    cleanup: EffectCleanup,\n    deps: Option(HookDependencies),\n  )\n}\n\nEffectResult(\n  cleanup: EffectCleanup,\n  deps: Option(HookDependencies),\n)\n\n\nSynonyms:\nsprocket/context.EffectResult\nsprocket/context EffectResult","url":"sprocket/context.html#EffectResult"},{"doc":"sprocket/context","title":"Element","content":"pub type Element {\n  Element(\n    tag: String,\n    attrs: List(Attribute),\n    children: List(Element),\n  )\n  Component(\n    component: FunctionalComponent(Dynamic),\n    props: Dynamic,\n  )\n  Fragment(children: List(Element))\n  Debug(id: String, meta: Option(Dynamic), element: Element)\n  Keyed(key: String, element: Element)\n  IgnoreUpdate(element: Element)\n  Provider(key: String, value: Dynamic, element: Element)\n  Text(text: String)\n}\n\nElement(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n)\n\n\nComponent(\n  component: FunctionalComponent(Dynamic),\n  props: Dynamic,\n)\n\n\nFragment(children: List(Element))\n\n\nDebug(id: String, meta: Option(Dynamic), element: Element)\n\n\nKeyed(key: String, element: Element)\n\n\nIgnoreUpdate(element: Element)\n\n\nProvider(key: String, value: Dynamic, element: Element)\n\n\nText(text: String)\n\n\nSynonyms:\nsprocket/context.Element\nsprocket/context Element","url":"sprocket/context.html#Element"},{"doc":"sprocket/context","title":"FunctionalComponent","content":"pub type FunctionalComponent(p) =\n  fn(Context, p) -&gt; #(Context, Element)\n\n\nSynonyms:\nsprocket/context.FunctionalComponent\nsprocket/context FunctionalComponent","url":"sprocket/context.html#FunctionalComponent"},{"doc":"sprocket/context","title":"HandlerFn","content":"pub type HandlerFn =\n  fn(Option(CallbackParam)) -&gt; Nil\n\n\nSynonyms:\nsprocket/context.HandlerFn\nsprocket/context HandlerFn","url":"sprocket/context.html#HandlerFn"},{"doc":"sprocket/context","title":"Hook","content":"pub type Hook {\n  Callback(\n    id: Unique,\n    callback: fn() -&gt; Nil,\n    prev: Option(CallbackResult),\n  )\n  Memo(id: Unique, value: Dynamic, prev: Option(MemoResult))\n  Effect(\n    id: Unique,\n    effect: fn() -&gt; EffectCleanup,\n    trigger: HookTrigger,\n    prev: Option(EffectResult),\n  )\n  Handler(id: Unique, handler_fn: HandlerFn)\n  Reducer(id: Unique, reducer: Dynamic, cleanup: fn() -&gt; Nil)\n  State(id: Unique, value: Dynamic)\n  Client(\n    id: Unique,\n    name: String,\n    handle_event: Option(ClientEventHandler),\n  )\n}\n\nCallback(\n  id: Unique,\n  callback: fn() -&gt; Nil,\n  prev: Option(CallbackResult),\n)\n\n\nMemo(id: Unique, value: Dynamic, prev: Option(MemoResult))\n\n\nEffect(\n  id: Unique,\n  effect: fn() -&gt; EffectCleanup,\n  trigger: HookTrigger,\n  prev: Option(EffectResult),\n)\n\n\nHandler(id: Unique, handler_fn: HandlerFn)\n\n\nReducer(id: Unique, reducer: Dynamic, cleanup: fn() -&gt; Nil)\n\n\nState(id: Unique, value: Dynamic)\n\n\nClient(\n  id: Unique,\n  name: String,\n  handle_event: Option(ClientEventHandler),\n)\n\n\nSynonyms:\nsprocket/context.Hook\nsprocket/context Hook","url":"sprocket/context.html#Hook"},{"doc":"sprocket/context","title":"HookDependencies","content":"pub type HookDependencies =\n  List(Dynamic)\n\n\nSynonyms:\nsprocket/context.HookDependencies\nsprocket/context HookDependencies","url":"sprocket/context.html#HookDependencies"},{"doc":"sprocket/context","title":"HookTrigger","content":"pub type HookTrigger {\n  OnMount\n  OnUpdate\n  WithDeps(deps: HookDependencies)\n}\n\nOnMount\n\n\nOnUpdate\n\n\nWithDeps(deps: HookDependencies)\n\n\nSynonyms:\nsprocket/context.HookTrigger\nsprocket/context HookTrigger","url":"sprocket/context.html#HookTrigger"},{"doc":"sprocket/context","title":"IdentifiableHandler","content":"pub type IdentifiableHandler {\n  IdentifiableHandler(id: Unique, handler_fn: HandlerFn)\n}\n\nIdentifiableHandler(id: Unique, handler_fn: HandlerFn)\n\n\nSynonyms:\nsprocket/context.IdentifiableHandler\nsprocket/context IdentifiableHandler","url":"sprocket/context.html#IdentifiableHandler"},{"doc":"sprocket/context","title":"MemoResult","content":"pub type MemoResult {\n  MemoResult(deps: Option(HookDependencies))\n}\n\nMemoResult(deps: Option(HookDependencies))\n\n\nSynonyms:\nsprocket/context.MemoResult\nsprocket/context MemoResult","url":"sprocket/context.html#MemoResult"},{"doc":"sprocket/context","title":"Updater","content":"pub type Updater(r) {\n  Updater(send: fn(r) -&gt; Result(Nil, Nil))\n}\n\nUpdater(send: fn(r) -&gt; Result(Nil, Nil))\n\n\nSynonyms:\nsprocket/context.Updater\nsprocket/context Updater","url":"sprocket/context.html#Updater"},{"doc":"sprocket/context","title":"callback_param_from_string","content":"pub fn callback_param_from_string(value: String) -&gt; CallbackParam\n\nSynonyms:\nsprocket/context.callback_param_from_string\nsprocket/context callback_param_from_string","url":"sprocket/context.html#callback_param_from_string"},{"doc":"sprocket/context","title":"compare_deps","content":"pub fn compare_deps(\n  prev_deps: List(Dynamic),\n  deps: List(Dynamic),\n) -&gt; Compared(List(Dynamic))\n\nSynonyms:\nsprocket/context.compare_deps\nsprocket/context compare_deps","url":"sprocket/context.html#compare_deps"},{"doc":"sprocket/context","title":"dep","content":"pub fn dep(dependency: a) -&gt; Dynamic\n\nSynonyms:\nsprocket/context.dep\nsprocket/context dep","url":"sprocket/context.html#dep"},{"doc":"sprocket/context","title":"dispatch_event","content":"pub fn dispatch_event(\n  ctx: Context,\n  id: Unique,\n  name: String,\n  payload: Option(String),\n) -&gt; Result(Nil, Nil)\n\nSynonyms:\nsprocket/context.dispatch_event\nsprocket/context dispatch_event","url":"sprocket/context.html#dispatch_event"},{"doc":"sprocket/context","title":"fetch_or_init_hook","content":"pub fn fetch_or_init_hook(\n  ctx: Context,\n  init: fn() -&gt; Hook,\n) -&gt; #(Context, Hook, Int)\n\nSynonyms:\nsprocket/context.fetch_or_init_hook\nsprocket/context fetch_or_init_hook","url":"sprocket/context.html#fetch_or_init_hook"},{"doc":"sprocket/context","title":"get_event_handler","content":"pub fn get_event_handler(\n  ctx: Context,\n  id: Unique,\n) -&gt; #(Context, Result(IdentifiableHandler, Nil))\n\nSynonyms:\nsprocket/context.get_event_handler\nsprocket/context get_event_handler","url":"sprocket/context.html#get_event_handler"},{"doc":"sprocket/context","title":"new","content":"pub fn new(\n  view: Element,\n  cuid_channel: Subject(Message),\n  dispatcher: Option(Dispatcher),\n  render_update: fn() -&gt; Nil,\n  update_hook: fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil,\n) -&gt; Context\n\nSynonyms:\nsprocket/context.new\nsprocket/context new","url":"sprocket/context.html#new"},{"doc":"sprocket/context","title":"prepare_for_reconciliation","content":"pub fn prepare_for_reconciliation(ctx: Context) -&gt; Context\n\nSynonyms:\nsprocket/context.prepare_for_reconciliation\nsprocket/context prepare_for_reconciliation","url":"sprocket/context.html#prepare_for_reconciliation"},{"doc":"sprocket/context","title":"provider","content":"pub fn provider(\n  key: String,\n  value: a,\n  element: Element,\n) -&gt; Element\n\nSynonyms:\nsprocket/context.provider\nsprocket/context provider","url":"sprocket/context.html#provider"},{"doc":"sprocket/context","title":"push_event_handler","content":"pub fn push_event_handler(\n  ctx: Context,\n  identifiable_cb: IdentifiableHandler,\n) -&gt; #(Context, Unique)\n\nSynonyms:\nsprocket/context.push_event_handler\nsprocket/context push_event_handler","url":"sprocket/context.html#push_event_handler"},{"doc":"sprocket/context","title":"update_hook","content":"pub fn update_hook(\n  ctx: Context,\n  hook: Hook,\n  index: Int,\n) -&gt; Context\n\nSynonyms:\nsprocket/context.update_hook\nsprocket/context update_hook","url":"sprocket/context.html#update_hook"},{"doc":"sprocket/context","title":"sprocket/context","content":"","url":"sprocket/context.html"},{"doc":"sprocket/html/elements","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;a&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a)\nSynonyms:\nsprocket/html/elements.a\nsprocket/html/elements a","url":"sprocket/html/elements.html#a"},{"doc":"sprocket/html/elements","title":"a_text","content":"pub fn a_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.a(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.a_text\nsprocket/html/elements a_text","url":"sprocket/html/elements.html#a_text"},{"doc":"sprocket/html/elements","title":"abbr","content":"pub fn abbr(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;abbr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/abbr)\nSynonyms:\nsprocket/html/elements.abbr\nsprocket/html/elements abbr","url":"sprocket/html/elements.html#abbr"},{"doc":"sprocket/html/elements","title":"address","content":"pub fn address(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;address&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/address)\nSynonyms:\nsprocket/html/elements.address\nsprocket/html/elements address","url":"sprocket/html/elements.html#address"},{"doc":"sprocket/html/elements","title":"area","content":"pub fn area(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;area /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/area)\nSynonyms:\nsprocket/html/elements.area\nsprocket/html/elements area","url":"sprocket/html/elements.html#area"},{"doc":"sprocket/html/elements","title":"article","content":"pub fn article(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;article&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/article)\nSynonyms:\nsprocket/html/elements.article\nsprocket/html/elements article","url":"sprocket/html/elements.html#article"},{"doc":"sprocket/html/elements","title":"article_text","content":"pub fn article_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.article(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.article_text\nsprocket/html/elements article_text","url":"sprocket/html/elements.html#article_text"},{"doc":"sprocket/html/elements","title":"aside","content":"pub fn aside(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;aside&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/aside)\nSynonyms:\nsprocket/html/elements.aside\nsprocket/html/elements aside","url":"sprocket/html/elements.html#aside"},{"doc":"sprocket/html/elements","title":"aside_text","content":"pub fn aside_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.aside(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.aside_text\nsprocket/html/elements aside_text","url":"sprocket/html/elements.html#aside_text"},{"doc":"sprocket/html/elements","title":"audio","content":"pub fn audio(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;audio&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/audio)\nSynonyms:\nsprocket/html/elements.audio\nsprocket/html/elements audio","url":"sprocket/html/elements.html#audio"},{"doc":"sprocket/html/elements","title":"audio_text","content":"pub fn audio_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.audio(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.audio_text\nsprocket/html/elements audio_text","url":"sprocket/html/elements.html#audio_text"},{"doc":"sprocket/html/elements","title":"b","content":"pub fn b(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;b&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/b)\nSynonyms:\nsprocket/html/elements.b\nsprocket/html/elements b","url":"sprocket/html/elements.html#b"},{"doc":"sprocket/html/elements","title":"b_text","content":"pub fn b_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.b(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.b_text\nsprocket/html/elements b_text","url":"sprocket/html/elements.html#b_text"},{"doc":"sprocket/html/elements","title":"base","content":"pub fn base(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;base /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/base)\nSynonyms:\nsprocket/html/elements.base\nsprocket/html/elements base","url":"sprocket/html/elements.html#base"},{"doc":"sprocket/html/elements","title":"bdi","content":"pub fn bdi(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;bdi&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/bdi)\nSynonyms:\nsprocket/html/elements.bdi\nsprocket/html/elements bdi","url":"sprocket/html/elements.html#bdi"},{"doc":"sprocket/html/elements","title":"bdi_text","content":"pub fn bdi_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.bdi(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.bdi_text\nsprocket/html/elements bdi_text","url":"sprocket/html/elements.html#bdi_text"},{"doc":"sprocket/html/elements","title":"bdo","content":"pub fn bdo(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;bdo&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/bdo)\nSynonyms:\nsprocket/html/elements.bdo\nsprocket/html/elements bdo","url":"sprocket/html/elements.html#bdo"},{"doc":"sprocket/html/elements","title":"bdo_text","content":"pub fn bdo_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.bdo(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.bdo_text\nsprocket/html/elements bdo_text","url":"sprocket/html/elements.html#bdo_text"},{"doc":"sprocket/html/elements","title":"blockquote","content":"pub fn blockquote(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;blockquote&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/blockquote)\nSynonyms:\nsprocket/html/elements.blockquote\nsprocket/html/elements blockquote","url":"sprocket/html/elements.html#blockquote"},{"doc":"sprocket/html/elements","title":"blockquote_text","content":"pub fn blockquote_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.blockquote(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.blockquote_text\nsprocket/html/elements blockquote_text","url":"sprocket/html/elements.html#blockquote_text"},{"doc":"sprocket/html/elements","title":"body","content":"pub fn body(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;body&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/body)\nSynonyms:\nsprocket/html/elements.body\nsprocket/html/elements body","url":"sprocket/html/elements.html#body"},{"doc":"sprocket/html/elements","title":"br","content":"pub fn br(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;br /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/br)\nSynonyms:\nsprocket/html/elements.br\nsprocket/html/elements br","url":"sprocket/html/elements.html#br"},{"doc":"sprocket/html/elements","title":"button","content":"pub fn button(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;button&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/button)\nSynonyms:\nsprocket/html/elements.button\nsprocket/html/elements button","url":"sprocket/html/elements.html#button"},{"doc":"sprocket/html/elements","title":"button_text","content":"pub fn button_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.button(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.button_text\nsprocket/html/elements button_text","url":"sprocket/html/elements.html#button_text"},{"doc":"sprocket/html/elements","title":"canvas","content":"pub fn canvas(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;canvas&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/canvas)\nSynonyms:\nsprocket/html/elements.canvas\nsprocket/html/elements canvas","url":"sprocket/html/elements.html#canvas"},{"doc":"sprocket/html/elements","title":"canvas_text","content":"pub fn canvas_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.canvas(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.canvas_text\nsprocket/html/elements canvas_text","url":"sprocket/html/elements.html#canvas_text"},{"doc":"sprocket/html/elements","title":"caption","content":"pub fn caption(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;caption&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/caption)\nSynonyms:\nsprocket/html/elements.caption\nsprocket/html/elements caption","url":"sprocket/html/elements.html#caption"},{"doc":"sprocket/html/elements","title":"caption_text","content":"pub fn caption_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.caption(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.caption_text\nsprocket/html/elements caption_text","url":"sprocket/html/elements.html#caption_text"},{"doc":"sprocket/html/elements","title":"cite","content":"pub fn cite(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;cite&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/cite)\nSynonyms:\nsprocket/html/elements.cite\nsprocket/html/elements cite","url":"sprocket/html/elements.html#cite"},{"doc":"sprocket/html/elements","title":"cite_text","content":"pub fn cite_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.cite(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.cite_text\nsprocket/html/elements cite_text","url":"sprocket/html/elements.html#cite_text"},{"doc":"sprocket/html/elements","title":"code","content":"pub fn code(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;code&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/code)\nSynonyms:\nsprocket/html/elements.code\nsprocket/html/elements code","url":"sprocket/html/elements.html#code"},{"doc":"sprocket/html/elements","title":"code_text","content":"pub fn code_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.code(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.code_text\nsprocket/html/elements code_text","url":"sprocket/html/elements.html#code_text"},{"doc":"sprocket/html/elements","title":"col","content":"pub fn col(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;col&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/col)\nSynonyms:\nsprocket/html/elements.col\nsprocket/html/elements col","url":"sprocket/html/elements.html#col"},{"doc":"sprocket/html/elements","title":"col_text","content":"pub fn col_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.col(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.col_text\nsprocket/html/elements col_text","url":"sprocket/html/elements.html#col_text"},{"doc":"sprocket/html/elements","title":"colgroup","content":"pub fn colgroup(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;colgroup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/colgroup)\nSynonyms:\nsprocket/html/elements.colgroup\nsprocket/html/elements colgroup","url":"sprocket/html/elements.html#colgroup"},{"doc":"sprocket/html/elements","title":"colgroup_text","content":"pub fn colgroup_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.colgroup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.colgroup_text\nsprocket/html/elements colgroup_text","url":"sprocket/html/elements.html#colgroup_text"},{"doc":"sprocket/html/elements","title":"data","content":"pub fn data(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;data&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/data)\nSynonyms:\nsprocket/html/elements.data\nsprocket/html/elements data","url":"sprocket/html/elements.html#data"},{"doc":"sprocket/html/elements","title":"data_text","content":"pub fn data_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.data(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.data_text\nsprocket/html/elements data_text","url":"sprocket/html/elements.html#data_text"},{"doc":"sprocket/html/elements","title":"datalist","content":"pub fn datalist(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;datalist&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/datalist)\nSynonyms:\nsprocket/html/elements.datalist\nsprocket/html/elements datalist","url":"sprocket/html/elements.html#datalist"},{"doc":"sprocket/html/elements","title":"datalist_text","content":"pub fn datalist_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.datalist(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.datalist_text\nsprocket/html/elements datalist_text","url":"sprocket/html/elements.html#datalist_text"},{"doc":"sprocket/html/elements","title":"dd","content":"pub fn dd(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;dd&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dd)\nSynonyms:\nsprocket/html/elements.dd\nsprocket/html/elements dd","url":"sprocket/html/elements.html#dd"},{"doc":"sprocket/html/elements","title":"dd_text","content":"pub fn dd_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.dd(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.dd_text\nsprocket/html/elements dd_text","url":"sprocket/html/elements.html#dd_text"},{"doc":"sprocket/html/elements","title":"debug","content":"pub fn debug(\n  id: String,\n  meta: Option(Dynamic),\n  element: Element,\n) -&gt; Element\n\nSynonyms:\nsprocket/html/elements.debug\nsprocket/html/elements debug","url":"sprocket/html/elements.html#debug"},{"doc":"sprocket/html/elements","title":"del","content":"pub fn del(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;del&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/del)\nSynonyms:\nsprocket/html/elements.del\nsprocket/html/elements del","url":"sprocket/html/elements.html#del"},{"doc":"sprocket/html/elements","title":"del_text","content":"pub fn del_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.del(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.del_text\nsprocket/html/elements del_text","url":"sprocket/html/elements.html#del_text"},{"doc":"sprocket/html/elements","title":"details","content":"pub fn details(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;details&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/details)\nSynonyms:\nsprocket/html/elements.details\nsprocket/html/elements details","url":"sprocket/html/elements.html#details"},{"doc":"sprocket/html/elements","title":"details_text","content":"pub fn details_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.details(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.details_text\nsprocket/html/elements details_text","url":"sprocket/html/elements.html#details_text"},{"doc":"sprocket/html/elements","title":"dfn","content":"pub fn dfn(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;dfn&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dfn)\nSynonyms:\nsprocket/html/elements.dfn\nsprocket/html/elements dfn","url":"sprocket/html/elements.html#dfn"},{"doc":"sprocket/html/elements","title":"dfn_text","content":"pub fn dfn_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.dfn(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.dfn_text\nsprocket/html/elements dfn_text","url":"sprocket/html/elements.html#dfn_text"},{"doc":"sprocket/html/elements","title":"dialog","content":"pub fn dialog(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;dialog&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dialog)\nSynonyms:\nsprocket/html/elements.dialog\nsprocket/html/elements dialog","url":"sprocket/html/elements.html#dialog"},{"doc":"sprocket/html/elements","title":"dialog_text","content":"pub fn dialog_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.dialog(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.dialog_text\nsprocket/html/elements dialog_text","url":"sprocket/html/elements.html#dialog_text"},{"doc":"sprocket/html/elements","title":"div","content":"pub fn div(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;div&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/div)\nSynonyms:\nsprocket/html/elements.div\nsprocket/html/elements div","url":"sprocket/html/elements.html#div"},{"doc":"sprocket/html/elements","title":"div_text","content":"pub fn div_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.div(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.div_text\nsprocket/html/elements div_text","url":"sprocket/html/elements.html#div_text"},{"doc":"sprocket/html/elements","title":"dl","content":"pub fn dl(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;dl&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dl)\nSynonyms:\nsprocket/html/elements.dl\nsprocket/html/elements dl","url":"sprocket/html/elements.html#dl"},{"doc":"sprocket/html/elements","title":"dl_text","content":"pub fn dl_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.dl(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.dl_text\nsprocket/html/elements dl_text","url":"sprocket/html/elements.html#dl_text"},{"doc":"sprocket/html/elements","title":"dt","content":"pub fn dt(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;dt&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dt)\nSynonyms:\nsprocket/html/elements.dt\nsprocket/html/elements dt","url":"sprocket/html/elements.html#dt"},{"doc":"sprocket/html/elements","title":"dt_text","content":"pub fn dt_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.dt(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.dt_text\nsprocket/html/elements dt_text","url":"sprocket/html/elements.html#dt_text"},{"doc":"sprocket/html/elements","title":"el","content":"pub fn el(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nsprocket/html/elements.el\nsprocket/html/elements el","url":"sprocket/html/elements.html#el"},{"doc":"sprocket/html/elements","title":"em","content":"pub fn em(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;em&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/em)\nSynonyms:\nsprocket/html/elements.em\nsprocket/html/elements em","url":"sprocket/html/elements.html#em"},{"doc":"sprocket/html/elements","title":"em_text","content":"pub fn em_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.em(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.em_text\nsprocket/html/elements em_text","url":"sprocket/html/elements.html#em_text"},{"doc":"sprocket/html/elements","title":"embed","content":"pub fn embed(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;embed&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/embed)\nSynonyms:\nsprocket/html/elements.embed\nsprocket/html/elements embed","url":"sprocket/html/elements.html#embed"},{"doc":"sprocket/html/elements","title":"embed_text","content":"pub fn embed_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.embed(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.embed_text\nsprocket/html/elements embed_text","url":"sprocket/html/elements.html#embed_text"},{"doc":"sprocket/html/elements","title":"fieldset","content":"pub fn fieldset(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;fieldset&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/fieldset)\nSynonyms:\nsprocket/html/elements.fieldset\nsprocket/html/elements fieldset","url":"sprocket/html/elements.html#fieldset"},{"doc":"sprocket/html/elements","title":"fieldset_text","content":"pub fn fieldset_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.fieldset(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.fieldset_text\nsprocket/html/elements fieldset_text","url":"sprocket/html/elements.html#fieldset_text"},{"doc":"sprocket/html/elements","title":"figcaption","content":"pub fn figcaption(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;figcaption&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/figcaption)\nSynonyms:\nsprocket/html/elements.figcaption\nsprocket/html/elements figcaption","url":"sprocket/html/elements.html#figcaption"},{"doc":"sprocket/html/elements","title":"figcaption_text","content":"pub fn figcaption_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.figcaption(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.figcaption_text\nsprocket/html/elements figcaption_text","url":"sprocket/html/elements.html#figcaption_text"},{"doc":"sprocket/html/elements","title":"figure","content":"pub fn figure(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;figure&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/figure)\nSynonyms:\nsprocket/html/elements.figure\nsprocket/html/elements figure","url":"sprocket/html/elements.html#figure"},{"doc":"sprocket/html/elements","title":"figure_text","content":"pub fn figure_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.figure(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.figure_text\nsprocket/html/elements figure_text","url":"sprocket/html/elements.html#figure_text"},{"doc":"sprocket/html/elements","title":"footer","content":"pub fn footer(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;footer&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/footer)\nSynonyms:\nsprocket/html/elements.footer\nsprocket/html/elements footer","url":"sprocket/html/elements.html#footer"},{"doc":"sprocket/html/elements","title":"footer_text","content":"pub fn footer_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.footer(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.footer_text\nsprocket/html/elements footer_text","url":"sprocket/html/elements.html#footer_text"},{"doc":"sprocket/html/elements","title":"form","content":"pub fn form(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;form&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form)\nSynonyms:\nsprocket/html/elements.form\nsprocket/html/elements form","url":"sprocket/html/elements.html#form"},{"doc":"sprocket/html/elements","title":"form_text","content":"pub fn form_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.form(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.form_text\nsprocket/html/elements form_text","url":"sprocket/html/elements.html#form_text"},{"doc":"sprocket/html/elements","title":"fragment","content":"pub fn fragment(children: List(Element)) -&gt; Element\n\nSynonyms:\nsprocket/html/elements.fragment\nsprocket/html/elements fragment","url":"sprocket/html/elements.html#fragment"},{"doc":"sprocket/html/elements","title":"h1","content":"pub fn h1(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;h1&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h1)\nSynonyms:\nsprocket/html/elements.h1\nsprocket/html/elements h1","url":"sprocket/html/elements.html#h1"},{"doc":"sprocket/html/elements","title":"h1_text","content":"pub fn h1_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.h1(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.h1_text\nsprocket/html/elements h1_text","url":"sprocket/html/elements.html#h1_text"},{"doc":"sprocket/html/elements","title":"h2","content":"pub fn h2(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;h2&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h2)\nSynonyms:\nsprocket/html/elements.h2\nsprocket/html/elements h2","url":"sprocket/html/elements.html#h2"},{"doc":"sprocket/html/elements","title":"h2_text","content":"pub fn h2_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.h2(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.h2_text\nsprocket/html/elements h2_text","url":"sprocket/html/elements.html#h2_text"},{"doc":"sprocket/html/elements","title":"h3","content":"pub fn h3(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;h3&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h3)\nSynonyms:\nsprocket/html/elements.h3\nsprocket/html/elements h3","url":"sprocket/html/elements.html#h3"},{"doc":"sprocket/html/elements","title":"h3_text","content":"pub fn h3_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.h3(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.h3_text\nsprocket/html/elements h3_text","url":"sprocket/html/elements.html#h3_text"},{"doc":"sprocket/html/elements","title":"h4","content":"pub fn h4(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;h4&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h4)\nSynonyms:\nsprocket/html/elements.h4\nsprocket/html/elements h4","url":"sprocket/html/elements.html#h4"},{"doc":"sprocket/html/elements","title":"h4_text","content":"pub fn h4_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.h4(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.h4_text\nsprocket/html/elements h4_text","url":"sprocket/html/elements.html#h4_text"},{"doc":"sprocket/html/elements","title":"h5","content":"pub fn h5(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;h5&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h5)\nSynonyms:\nsprocket/html/elements.h5\nsprocket/html/elements h5","url":"sprocket/html/elements.html#h5"},{"doc":"sprocket/html/elements","title":"h5_text","content":"pub fn h5_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.h5(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.h5_text\nsprocket/html/elements h5_text","url":"sprocket/html/elements.html#h5_text"},{"doc":"sprocket/html/elements","title":"h6","content":"pub fn h6(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;h6&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h6)\nSynonyms:\nsprocket/html/elements.h6\nsprocket/html/elements h6","url":"sprocket/html/elements.html#h6"},{"doc":"sprocket/html/elements","title":"h6_text","content":"pub fn h6_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.h6(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.h6_text\nsprocket/html/elements h6_text","url":"sprocket/html/elements.html#h6_text"},{"doc":"sprocket/html/elements","title":"head","content":"pub fn head(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;head&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/head)\nSynonyms:\nsprocket/html/elements.head\nsprocket/html/elements head","url":"sprocket/html/elements.html#head"},{"doc":"sprocket/html/elements","title":"header","content":"pub fn header(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;header&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/header)\nSynonyms:\nsprocket/html/elements.header\nsprocket/html/elements header","url":"sprocket/html/elements.html#header"},{"doc":"sprocket/html/elements","title":"header_text","content":"pub fn header_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.header(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.header_text\nsprocket/html/elements header_text","url":"sprocket/html/elements.html#header_text"},{"doc":"sprocket/html/elements","title":"hr","content":"pub fn hr(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;hr /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/hr)\nSynonyms:\nsprocket/html/elements.hr\nsprocket/html/elements hr","url":"sprocket/html/elements.html#hr"},{"doc":"sprocket/html/elements","title":"html","content":"pub fn html(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;html&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/html)\nSynonyms:\nsprocket/html/elements.html\nsprocket/html/elements html","url":"sprocket/html/elements.html#html"},{"doc":"sprocket/html/elements","title":"i","content":"pub fn i(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;i&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/i)\nSynonyms:\nsprocket/html/elements.i\nsprocket/html/elements i","url":"sprocket/html/elements.html#i"},{"doc":"sprocket/html/elements","title":"i_text","content":"pub fn i_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.i(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.i_text\nsprocket/html/elements i_text","url":"sprocket/html/elements.html#i_text"},{"doc":"sprocket/html/elements","title":"iframe","content":"pub fn iframe(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;iframe&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/iframe)\nSynonyms:\nsprocket/html/elements.iframe\nsprocket/html/elements iframe","url":"sprocket/html/elements.html#iframe"},{"doc":"sprocket/html/elements","title":"iframe_text","content":"pub fn iframe_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.iframe(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.iframe_text\nsprocket/html/elements iframe_text","url":"sprocket/html/elements.html#iframe_text"},{"doc":"sprocket/html/elements","title":"ignore","content":"pub fn ignore(element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html/elements.ignore\nsprocket/html/elements ignore","url":"sprocket/html/elements.html#ignore"},{"doc":"sprocket/html/elements","title":"ignore_while","content":"pub fn ignore_while(expr: Bool, element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html/elements.ignore_while\nsprocket/html/elements ignore_while","url":"sprocket/html/elements.html#ignore_while"},{"doc":"sprocket/html/elements","title":"img","content":"pub fn img(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;img /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img)\nSynonyms:\nsprocket/html/elements.img\nsprocket/html/elements img","url":"sprocket/html/elements.html#img"},{"doc":"sprocket/html/elements","title":"input","content":"pub fn input(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;input /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input)\nSynonyms:\nsprocket/html/elements.input\nsprocket/html/elements input","url":"sprocket/html/elements.html#input"},{"doc":"sprocket/html/elements","title":"ins","content":"pub fn ins(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;ins&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ins)\nSynonyms:\nsprocket/html/elements.ins\nsprocket/html/elements ins","url":"sprocket/html/elements.html#ins"},{"doc":"sprocket/html/elements","title":"ins_text","content":"pub fn ins_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.ins(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.ins_text\nsprocket/html/elements ins_text","url":"sprocket/html/elements.html#ins_text"},{"doc":"sprocket/html/elements","title":"kbd","content":"pub fn kbd(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;kbd&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/kbd)\nSynonyms:\nsprocket/html/elements.kbd\nsprocket/html/elements kbd","url":"sprocket/html/elements.html#kbd"},{"doc":"sprocket/html/elements","title":"kbd_text","content":"pub fn kbd_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.kbd(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.kbd_text\nsprocket/html/elements kbd_text","url":"sprocket/html/elements.html#kbd_text"},{"doc":"sprocket/html/elements","title":"keyed","content":"pub fn keyed(key: String, element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html/elements.keyed\nsprocket/html/elements keyed","url":"sprocket/html/elements.html#keyed"},{"doc":"sprocket/html/elements","title":"label","content":"pub fn label(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;label&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/label)\nSynonyms:\nsprocket/html/elements.label\nsprocket/html/elements label","url":"sprocket/html/elements.html#label"},{"doc":"sprocket/html/elements","title":"label_text","content":"pub fn label_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.label(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.label_text\nsprocket/html/elements label_text","url":"sprocket/html/elements.html#label_text"},{"doc":"sprocket/html/elements","title":"legend","content":"pub fn legend(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;legend&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/legend)\nSynonyms:\nsprocket/html/elements.legend\nsprocket/html/elements legend","url":"sprocket/html/elements.html#legend"},{"doc":"sprocket/html/elements","title":"legend_text","content":"pub fn legend_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.legend(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.legend_text\nsprocket/html/elements legend_text","url":"sprocket/html/elements.html#legend_text"},{"doc":"sprocket/html/elements","title":"li","content":"pub fn li(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;li&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/li)\nSynonyms:\nsprocket/html/elements.li\nsprocket/html/elements li","url":"sprocket/html/elements.html#li"},{"doc":"sprocket/html/elements","title":"li_text","content":"pub fn li_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.li(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.li_text\nsprocket/html/elements li_text","url":"sprocket/html/elements.html#li_text"},{"doc":"sprocket/html/elements","title":"link","content":"pub fn link(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;link /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link)\nSynonyms:\nsprocket/html/elements.link\nsprocket/html/elements link","url":"sprocket/html/elements.html#link"},{"doc":"sprocket/html/elements","title":"main","content":"pub fn main(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;main&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/main)\nSynonyms:\nsprocket/html/elements.main\nsprocket/html/elements main","url":"sprocket/html/elements.html#main"},{"doc":"sprocket/html/elements","title":"main_text","content":"pub fn main_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.main(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.main_text\nsprocket/html/elements main_text","url":"sprocket/html/elements.html#main_text"},{"doc":"sprocket/html/elements","title":"map","content":"pub fn map(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;map&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/map)\nSynonyms:\nsprocket/html/elements.map\nsprocket/html/elements map","url":"sprocket/html/elements.html#map"},{"doc":"sprocket/html/elements","title":"map_text","content":"pub fn map_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.map(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.map_text\nsprocket/html/elements map_text","url":"sprocket/html/elements.html#map_text"},{"doc":"sprocket/html/elements","title":"mark","content":"pub fn mark(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;mark&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/mark)\nSynonyms:\nsprocket/html/elements.mark\nsprocket/html/elements mark","url":"sprocket/html/elements.html#mark"},{"doc":"sprocket/html/elements","title":"mark_text","content":"pub fn mark_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.mark(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.mark_text\nsprocket/html/elements mark_text","url":"sprocket/html/elements.html#mark_text"},{"doc":"sprocket/html/elements","title":"math","content":"pub fn math(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;math&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/math)\nSynonyms:\nsprocket/html/elements.math\nsprocket/html/elements math","url":"sprocket/html/elements.html#math"},{"doc":"sprocket/html/elements","title":"math_text","content":"pub fn math_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.math(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.math_text\nsprocket/html/elements math_text","url":"sprocket/html/elements.html#math_text"},{"doc":"sprocket/html/elements","title":"menu","content":"pub fn menu(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;menu&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/menu)\nSynonyms:\nsprocket/html/elements.menu\nsprocket/html/elements menu","url":"sprocket/html/elements.html#menu"},{"doc":"sprocket/html/elements","title":"menu_text","content":"pub fn menu_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.menu(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.menu_text\nsprocket/html/elements menu_text","url":"sprocket/html/elements.html#menu_text"},{"doc":"sprocket/html/elements","title":"menuitem","content":"pub fn menuitem(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;menuitem&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/menuitem)\nSynonyms:\nsprocket/html/elements.menuitem\nsprocket/html/elements menuitem","url":"sprocket/html/elements.html#menuitem"},{"doc":"sprocket/html/elements","title":"menuitem_text","content":"pub fn menuitem_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.menuitem(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.menuitem_text\nsprocket/html/elements menuitem_text","url":"sprocket/html/elements.html#menuitem_text"},{"doc":"sprocket/html/elements","title":"meta","content":"pub fn meta(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;meta /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta)\nSynonyms:\nsprocket/html/elements.meta\nsprocket/html/elements meta","url":"sprocket/html/elements.html#meta"},{"doc":"sprocket/html/elements","title":"meter","content":"pub fn meter(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;meter&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meter)\nSynonyms:\nsprocket/html/elements.meter\nsprocket/html/elements meter","url":"sprocket/html/elements.html#meter"},{"doc":"sprocket/html/elements","title":"meter_text","content":"pub fn meter_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.meter(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.meter_text\nsprocket/html/elements meter_text","url":"sprocket/html/elements.html#meter_text"},{"doc":"sprocket/html/elements","title":"nav","content":"pub fn nav(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;nav&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/nav)\nSynonyms:\nsprocket/html/elements.nav\nsprocket/html/elements nav","url":"sprocket/html/elements.html#nav"},{"doc":"sprocket/html/elements","title":"nav_text","content":"pub fn nav_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.nav(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.nav_text\nsprocket/html/elements nav_text","url":"sprocket/html/elements.html#nav_text"},{"doc":"sprocket/html/elements","title":"noscript","content":"pub fn noscript(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;noscript&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/noscript)\nSynonyms:\nsprocket/html/elements.noscript\nsprocket/html/elements noscript","url":"sprocket/html/elements.html#noscript"},{"doc":"sprocket/html/elements","title":"noscript_text","content":"pub fn noscript_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.noscript(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.noscript_text\nsprocket/html/elements noscript_text","url":"sprocket/html/elements.html#noscript_text"},{"doc":"sprocket/html/elements","title":"object","content":"pub fn object(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;object&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/object)\nSynonyms:\nsprocket/html/elements.object\nsprocket/html/elements object","url":"sprocket/html/elements.html#object"},{"doc":"sprocket/html/elements","title":"object_text","content":"pub fn object_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.object(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.object_text\nsprocket/html/elements object_text","url":"sprocket/html/elements.html#object_text"},{"doc":"sprocket/html/elements","title":"ol","content":"pub fn ol(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;ol&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ol)\nSynonyms:\nsprocket/html/elements.ol\nsprocket/html/elements ol","url":"sprocket/html/elements.html#ol"},{"doc":"sprocket/html/elements","title":"ol_text","content":"pub fn ol_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.ol(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.ol_text\nsprocket/html/elements ol_text","url":"sprocket/html/elements.html#ol_text"},{"doc":"sprocket/html/elements","title":"optgroup","content":"pub fn optgroup(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;optgroup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/optgroup)\nSynonyms:\nsprocket/html/elements.optgroup\nsprocket/html/elements optgroup","url":"sprocket/html/elements.html#optgroup"},{"doc":"sprocket/html/elements","title":"optgroup_text","content":"pub fn optgroup_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.optgroup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.optgroup_text\nsprocket/html/elements optgroup_text","url":"sprocket/html/elements.html#optgroup_text"},{"doc":"sprocket/html/elements","title":"option","content":"pub fn option(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;option&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/option)\nSynonyms:\nsprocket/html/elements.option\nsprocket/html/elements option","url":"sprocket/html/elements.html#option"},{"doc":"sprocket/html/elements","title":"option_text","content":"pub fn option_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.option(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.option_text\nsprocket/html/elements option_text","url":"sprocket/html/elements.html#option_text"},{"doc":"sprocket/html/elements","title":"output","content":"pub fn output(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;output&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/output)\nSynonyms:\nsprocket/html/elements.output\nsprocket/html/elements output","url":"sprocket/html/elements.html#output"},{"doc":"sprocket/html/elements","title":"output_text","content":"pub fn output_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.output(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.output_text\nsprocket/html/elements output_text","url":"sprocket/html/elements.html#output_text"},{"doc":"sprocket/html/elements","title":"p","content":"pub fn p(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;p&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/p)\nSynonyms:\nsprocket/html/elements.p\nsprocket/html/elements p","url":"sprocket/html/elements.html#p"},{"doc":"sprocket/html/elements","title":"p_text","content":"pub fn p_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.p(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.p_text\nsprocket/html/elements p_text","url":"sprocket/html/elements.html#p_text"},{"doc":"sprocket/html/elements","title":"param","content":"pub fn param(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;param&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/param)\nSynonyms:\nsprocket/html/elements.param\nsprocket/html/elements param","url":"sprocket/html/elements.html#param"},{"doc":"sprocket/html/elements","title":"param_text","content":"pub fn param_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.param(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.param_text\nsprocket/html/elements param_text","url":"sprocket/html/elements.html#param_text"},{"doc":"sprocket/html/elements","title":"picture","content":"pub fn picture(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;picture&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/picture)\nSynonyms:\nsprocket/html/elements.picture\nsprocket/html/elements picture","url":"sprocket/html/elements.html#picture"},{"doc":"sprocket/html/elements","title":"picture_text","content":"pub fn picture_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.picture(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.picture_text\nsprocket/html/elements picture_text","url":"sprocket/html/elements.html#picture_text"},{"doc":"sprocket/html/elements","title":"pre","content":"pub fn pre(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;pre&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/pre)\nSynonyms:\nsprocket/html/elements.pre\nsprocket/html/elements pre","url":"sprocket/html/elements.html#pre"},{"doc":"sprocket/html/elements","title":"pre_text","content":"pub fn pre_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.pre(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.pre_text\nsprocket/html/elements pre_text","url":"sprocket/html/elements.html#pre_text"},{"doc":"sprocket/html/elements","title":"progress","content":"pub fn progress(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;progress&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/progress)\nSynonyms:\nsprocket/html/elements.progress\nsprocket/html/elements progress","url":"sprocket/html/elements.html#progress"},{"doc":"sprocket/html/elements","title":"progress_text","content":"pub fn progress_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.progress(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.progress_text\nsprocket/html/elements progress_text","url":"sprocket/html/elements.html#progress_text"},{"doc":"sprocket/html/elements","title":"q","content":"pub fn q(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;q&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/q)\nSynonyms:\nsprocket/html/elements.q\nsprocket/html/elements q","url":"sprocket/html/elements.html#q"},{"doc":"sprocket/html/elements","title":"q_text","content":"pub fn q_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.q(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.q_text\nsprocket/html/elements q_text","url":"sprocket/html/elements.html#q_text"},{"doc":"sprocket/html/elements","title":"rp","content":"pub fn rp(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;rp&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/rp)\nSynonyms:\nsprocket/html/elements.rp\nsprocket/html/elements rp","url":"sprocket/html/elements.html#rp"},{"doc":"sprocket/html/elements","title":"rp_text","content":"pub fn rp_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.rp(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.rp_text\nsprocket/html/elements rp_text","url":"sprocket/html/elements.html#rp_text"},{"doc":"sprocket/html/elements","title":"rt","content":"pub fn rt(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;rt&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/rt)\nSynonyms:\nsprocket/html/elements.rt\nsprocket/html/elements rt","url":"sprocket/html/elements.html#rt"},{"doc":"sprocket/html/elements","title":"rt_text","content":"pub fn rt_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.rt(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.rt_text\nsprocket/html/elements rt_text","url":"sprocket/html/elements.html#rt_text"},{"doc":"sprocket/html/elements","title":"ruby","content":"pub fn ruby(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;ruby&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ruby)\nSynonyms:\nsprocket/html/elements.ruby\nsprocket/html/elements ruby","url":"sprocket/html/elements.html#ruby"},{"doc":"sprocket/html/elements","title":"ruby_text","content":"pub fn ruby_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.ruby(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.ruby_text\nsprocket/html/elements ruby_text","url":"sprocket/html/elements.html#ruby_text"},{"doc":"sprocket/html/elements","title":"s","content":"pub fn s(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;s&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/s)\nSynonyms:\nsprocket/html/elements.s\nsprocket/html/elements s","url":"sprocket/html/elements.html#s"},{"doc":"sprocket/html/elements","title":"s_text","content":"pub fn s_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.s(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.s_text\nsprocket/html/elements s_text","url":"sprocket/html/elements.html#s_text"},{"doc":"sprocket/html/elements","title":"samp","content":"pub fn samp(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;samp&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/samp)\nSynonyms:\nsprocket/html/elements.samp\nsprocket/html/elements samp","url":"sprocket/html/elements.html#samp"},{"doc":"sprocket/html/elements","title":"samp_text","content":"pub fn samp_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.samp(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.samp_text\nsprocket/html/elements samp_text","url":"sprocket/html/elements.html#samp_text"},{"doc":"sprocket/html/elements","title":"script","content":"pub fn script(\n  attrs: List(Attribute),\n  body: Option(String),\n) -&gt; Element\n The [HTML `&lt;script&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/script)\nSynonyms:\nsprocket/html/elements.script\nsprocket/html/elements script","url":"sprocket/html/elements.html#script"},{"doc":"sprocket/html/elements","title":"section","content":"pub fn section(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;section&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/section)\nSynonyms:\nsprocket/html/elements.section\nsprocket/html/elements section","url":"sprocket/html/elements.html#section"},{"doc":"sprocket/html/elements","title":"section_text","content":"pub fn section_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.section(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.section_text\nsprocket/html/elements section_text","url":"sprocket/html/elements.html#section_text"},{"doc":"sprocket/html/elements","title":"select","content":"pub fn select(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;select&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/select)\nSynonyms:\nsprocket/html/elements.select\nsprocket/html/elements select","url":"sprocket/html/elements.html#select"},{"doc":"sprocket/html/elements","title":"select_text","content":"pub fn select_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.select(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.select_text\nsprocket/html/elements select_text","url":"sprocket/html/elements.html#select_text"},{"doc":"sprocket/html/elements","title":"small","content":"pub fn small(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;small&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/small)\nSynonyms:\nsprocket/html/elements.small\nsprocket/html/elements small","url":"sprocket/html/elements.html#small"},{"doc":"sprocket/html/elements","title":"small_text","content":"pub fn small_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.small(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.small_text\nsprocket/html/elements small_text","url":"sprocket/html/elements.html#small_text"},{"doc":"sprocket/html/elements","title":"source","content":"pub fn source(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;source /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/source)\nSynonyms:\nsprocket/html/elements.source\nsprocket/html/elements source","url":"sprocket/html/elements.html#source"},{"doc":"sprocket/html/elements","title":"span","content":"pub fn span(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;span&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/span)\nSynonyms:\nsprocket/html/elements.span\nsprocket/html/elements span","url":"sprocket/html/elements.html#span"},{"doc":"sprocket/html/elements","title":"span_text","content":"pub fn span_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.span(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.span_text\nsprocket/html/elements span_text","url":"sprocket/html/elements.html#span_text"},{"doc":"sprocket/html/elements","title":"strong","content":"pub fn strong(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;strong&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/strong)\nSynonyms:\nsprocket/html/elements.strong\nsprocket/html/elements strong","url":"sprocket/html/elements.html#strong"},{"doc":"sprocket/html/elements","title":"strong_text","content":"pub fn strong_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.strong(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.strong_text\nsprocket/html/elements strong_text","url":"sprocket/html/elements.html#strong_text"},{"doc":"sprocket/html/elements","title":"style","content":"pub fn style(\n  attrs: List(Attribute),\n  body: Option(String),\n) -&gt; Element\n The [HTML `&lt;style&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/style)\nSynonyms:\nsprocket/html/elements.style\nsprocket/html/elements style","url":"sprocket/html/elements.html#style"},{"doc":"sprocket/html/elements","title":"sub","content":"pub fn sub(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;sub&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/sub)\nSynonyms:\nsprocket/html/elements.sub\nsprocket/html/elements sub","url":"sprocket/html/elements.html#sub"},{"doc":"sprocket/html/elements","title":"sub_text","content":"pub fn sub_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.sub(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.sub_text\nsprocket/html/elements sub_text","url":"sprocket/html/elements.html#sub_text"},{"doc":"sprocket/html/elements","title":"summary","content":"pub fn summary(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;summary&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/summary)\nSynonyms:\nsprocket/html/elements.summary\nsprocket/html/elements summary","url":"sprocket/html/elements.html#summary"},{"doc":"sprocket/html/elements","title":"summary_text","content":"pub fn summary_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.summary(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.summary_text\nsprocket/html/elements summary_text","url":"sprocket/html/elements.html#summary_text"},{"doc":"sprocket/html/elements","title":"sup","content":"pub fn sup(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;sup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/sup)\nSynonyms:\nsprocket/html/elements.sup\nsprocket/html/elements sup","url":"sprocket/html/elements.html#sup"},{"doc":"sprocket/html/elements","title":"sup_text","content":"pub fn sup_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.sup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.sup_text\nsprocket/html/elements sup_text","url":"sprocket/html/elements.html#sup_text"},{"doc":"sprocket/html/elements","title":"svg","content":"pub fn svg(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;svg&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/svg)\nSynonyms:\nsprocket/html/elements.svg\nsprocket/html/elements svg","url":"sprocket/html/elements.html#svg"},{"doc":"sprocket/html/elements","title":"svg_text","content":"pub fn svg_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.svg(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.svg_text\nsprocket/html/elements svg_text","url":"sprocket/html/elements.html#svg_text"},{"doc":"sprocket/html/elements","title":"table","content":"pub fn table(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;table&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/table)\nSynonyms:\nsprocket/html/elements.table\nsprocket/html/elements table","url":"sprocket/html/elements.html#table"},{"doc":"sprocket/html/elements","title":"table_text","content":"pub fn table_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.table(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.table_text\nsprocket/html/elements table_text","url":"sprocket/html/elements.html#table_text"},{"doc":"sprocket/html/elements","title":"tbody","content":"pub fn tbody(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;tbody&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tbody)\nSynonyms:\nsprocket/html/elements.tbody\nsprocket/html/elements tbody","url":"sprocket/html/elements.html#tbody"},{"doc":"sprocket/html/elements","title":"tbody_text","content":"pub fn tbody_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.tbody(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.tbody_text\nsprocket/html/elements tbody_text","url":"sprocket/html/elements.html#tbody_text"},{"doc":"sprocket/html/elements","title":"td","content":"pub fn td(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;td&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/td)\nSynonyms:\nsprocket/html/elements.td\nsprocket/html/elements td","url":"sprocket/html/elements.html#td"},{"doc":"sprocket/html/elements","title":"td_text","content":"pub fn td_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.td(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.td_text\nsprocket/html/elements td_text","url":"sprocket/html/elements.html#td_text"},{"doc":"sprocket/html/elements","title":"text","content":"pub fn text(text: String) -&gt; Element\n\nSynonyms:\nsprocket/html/elements.text\nsprocket/html/elements text","url":"sprocket/html/elements.html#text"},{"doc":"sprocket/html/elements","title":"textarea","content":"pub fn textarea(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;textarea&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/textarea)\nSynonyms:\nsprocket/html/elements.textarea\nsprocket/html/elements textarea","url":"sprocket/html/elements.html#textarea"},{"doc":"sprocket/html/elements","title":"textarea_text","content":"pub fn textarea_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.textarea(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.textarea_text\nsprocket/html/elements textarea_text","url":"sprocket/html/elements.html#textarea_text"},{"doc":"sprocket/html/elements","title":"tfoot","content":"pub fn tfoot(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;tfoot&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tfoot)\nSynonyms:\nsprocket/html/elements.tfoot\nsprocket/html/elements tfoot","url":"sprocket/html/elements.html#tfoot"},{"doc":"sprocket/html/elements","title":"tfoot_text","content":"pub fn tfoot_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.tfoot(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.tfoot_text\nsprocket/html/elements tfoot_text","url":"sprocket/html/elements.html#tfoot_text"},{"doc":"sprocket/html/elements","title":"th","content":"pub fn th(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;th&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/th)\nSynonyms:\nsprocket/html/elements.th\nsprocket/html/elements th","url":"sprocket/html/elements.html#th"},{"doc":"sprocket/html/elements","title":"th_text","content":"pub fn th_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.th(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.th_text\nsprocket/html/elements th_text","url":"sprocket/html/elements.html#th_text"},{"doc":"sprocket/html/elements","title":"thead","content":"pub fn thead(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;thead&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/thead)\nSynonyms:\nsprocket/html/elements.thead\nsprocket/html/elements thead","url":"sprocket/html/elements.html#thead"},{"doc":"sprocket/html/elements","title":"thead_text","content":"pub fn thead_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.thead(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.thead_text\nsprocket/html/elements thead_text","url":"sprocket/html/elements.html#thead_text"},{"doc":"sprocket/html/elements","title":"time","content":"pub fn time(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;time&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/time)\nSynonyms:\nsprocket/html/elements.time\nsprocket/html/elements time","url":"sprocket/html/elements.html#time"},{"doc":"sprocket/html/elements","title":"time_text","content":"pub fn time_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.time(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.time_text\nsprocket/html/elements time_text","url":"sprocket/html/elements.html#time_text"},{"doc":"sprocket/html/elements","title":"title","content":"pub fn title(title: String) -&gt; Element\n The HTML [`&lt;title&gt;`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/title) element\nSynonyms:\nsprocket/html/elements.title\nsprocket/html/elements title","url":"sprocket/html/elements.html#title"},{"doc":"sprocket/html/elements","title":"tr","content":"pub fn tr(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;tr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tr)\nSynonyms:\nsprocket/html/elements.tr\nsprocket/html/elements tr","url":"sprocket/html/elements.html#tr"},{"doc":"sprocket/html/elements","title":"tr_text","content":"pub fn tr_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.tr(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.tr_text\nsprocket/html/elements tr_text","url":"sprocket/html/elements.html#tr_text"},{"doc":"sprocket/html/elements","title":"track","content":"pub fn track(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;track /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/track)\nSynonyms:\nsprocket/html/elements.track\nsprocket/html/elements track","url":"sprocket/html/elements.html#track"},{"doc":"sprocket/html/elements","title":"u","content":"pub fn u(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;u&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/u)\nSynonyms:\nsprocket/html/elements.u\nsprocket/html/elements u","url":"sprocket/html/elements.html#u"},{"doc":"sprocket/html/elements","title":"u_text","content":"pub fn u_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.u(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.u_text\nsprocket/html/elements u_text","url":"sprocket/html/elements.html#u_text"},{"doc":"sprocket/html/elements","title":"ul","content":"pub fn ul(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;ul&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ul)\nSynonyms:\nsprocket/html/elements.ul\nsprocket/html/elements ul","url":"sprocket/html/elements.html#ul"},{"doc":"sprocket/html/elements","title":"ul_text","content":"pub fn ul_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.ul(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.ul_text\nsprocket/html/elements ul_text","url":"sprocket/html/elements.html#ul_text"},{"doc":"sprocket/html/elements","title":"var","content":"pub fn var(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;var&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/var)\nSynonyms:\nsprocket/html/elements.var\nsprocket/html/elements var","url":"sprocket/html/elements.html#var"},{"doc":"sprocket/html/elements","title":"var_text","content":"pub fn var_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.var(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.var_text\nsprocket/html/elements var_text","url":"sprocket/html/elements.html#var_text"},{"doc":"sprocket/html/elements","title":"video","content":"pub fn video(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;video&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/video)\nSynonyms:\nsprocket/html/elements.video\nsprocket/html/elements video","url":"sprocket/html/elements.html#video"},{"doc":"sprocket/html/elements","title":"video_text","content":"pub fn video_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.video(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.video_text\nsprocket/html/elements video_text","url":"sprocket/html/elements.html#video_text"},{"doc":"sprocket/html/elements","title":"wbr","content":"pub fn wbr(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [HTML `&lt;wbr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/wbr)\nSynonyms:\nsprocket/html/elements.wbr\nsprocket/html/elements wbr","url":"sprocket/html/elements.html#wbr"},{"doc":"sprocket/html/elements","title":"wbr_text","content":"pub fn wbr_text(\n  attrs: List(Attribute),\n  text inner_text: String,\n) -&gt; Element\n Shorthand for `html.wbr(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html/elements.wbr_text\nsprocket/html/elements wbr_text","url":"sprocket/html/elements.html#wbr_text"},{"doc":"sprocket/html/elements","title":"sprocket/html/elements","content":"","url":"sprocket/html/elements.html"},{"doc":"sprocket/html/svg/elements","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;a&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/a)\nSynonyms:\nsprocket/html/svg/elements.a\nsprocket/html/svg/elements a","url":"sprocket/html/svg/elements.html#a"},{"doc":"sprocket/html/svg/elements","title":"animate","content":"pub fn animate(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;animate&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animate)\nSynonyms:\nsprocket/html/svg/elements.animate\nsprocket/html/svg/elements animate","url":"sprocket/html/svg/elements.html#animate"},{"doc":"sprocket/html/svg/elements","title":"animate_motion","content":"pub fn animate_motion(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;animateMotion&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animateMotion)\nSynonyms:\nsprocket/html/svg/elements.animate_motion\nsprocket/html/svg/elements animate_motion","url":"sprocket/html/svg/elements.html#animate_motion"},{"doc":"sprocket/html/svg/elements","title":"animate_transform","content":"pub fn animate_transform(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;animateTransform&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animateTransform)\nSynonyms:\nsprocket/html/svg/elements.animate_transform\nsprocket/html/svg/elements animate_transform","url":"sprocket/html/svg/elements.html#animate_transform"},{"doc":"sprocket/html/svg/elements","title":"circle","content":"pub fn circle(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;circle&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/circle)\nSynonyms:\nsprocket/html/svg/elements.circle\nsprocket/html/svg/elements circle","url":"sprocket/html/svg/elements.html#circle"},{"doc":"sprocket/html/svg/elements","title":"clip_path","content":"pub fn clip_path(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;clipPath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/clipPath)\nSynonyms:\nsprocket/html/svg/elements.clip_path\nsprocket/html/svg/elements clip_path","url":"sprocket/html/svg/elements.html#clip_path"},{"doc":"sprocket/html/svg/elements","title":"defs","content":"pub fn defs(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;defs&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/defs)\nSynonyms:\nsprocket/html/svg/elements.defs\nsprocket/html/svg/elements defs","url":"sprocket/html/svg/elements.html#defs"},{"doc":"sprocket/html/svg/elements","title":"desc","content":"pub fn desc(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;desc&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/desc)\nSynonyms:\nsprocket/html/svg/elements.desc\nsprocket/html/svg/elements desc","url":"sprocket/html/svg/elements.html#desc"},{"doc":"sprocket/html/svg/elements","title":"ellipse","content":"pub fn ellipse(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;ellipse&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/ellipse)\nSynonyms:\nsprocket/html/svg/elements.ellipse\nsprocket/html/svg/elements ellipse","url":"sprocket/html/svg/elements.html#ellipse"},{"doc":"sprocket/html/svg/elements","title":"fe_blend","content":"pub fn fe_blend(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feBlend&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feBlend)\nSynonyms:\nsprocket/html/svg/elements.fe_blend\nsprocket/html/svg/elements fe_blend","url":"sprocket/html/svg/elements.html#fe_blend"},{"doc":"sprocket/html/svg/elements","title":"fe_color_matrix","content":"pub fn fe_color_matrix(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feColorMatrix&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feColorMatrix)\nSynonyms:\nsprocket/html/svg/elements.fe_color_matrix\nsprocket/html/svg/elements fe_color_matrix","url":"sprocket/html/svg/elements.html#fe_color_matrix"},{"doc":"sprocket/html/svg/elements","title":"fe_component_transfer","content":"pub fn fe_component_transfer(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feComponentTransfer&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComponentTransfer)\nSynonyms:\nsprocket/html/svg/elements.fe_component_transfer\nsprocket/html/svg/elements fe_component_transfer","url":"sprocket/html/svg/elements.html#fe_component_transfer"},{"doc":"sprocket/html/svg/elements","title":"fe_composite","content":"pub fn fe_composite(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feComposite&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComposite)\nSynonyms:\nsprocket/html/svg/elements.fe_composite\nsprocket/html/svg/elements fe_composite","url":"sprocket/html/svg/elements.html#fe_composite"},{"doc":"sprocket/html/svg/elements","title":"fe_convolve_matrix","content":"pub fn fe_convolve_matrix(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feConvolveMatrix&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feConvolveMatrix)\nSynonyms:\nsprocket/html/svg/elements.fe_convolve_matrix\nsprocket/html/svg/elements fe_convolve_matrix","url":"sprocket/html/svg/elements.html#fe_convolve_matrix"},{"doc":"sprocket/html/svg/elements","title":"fe_diffuse_lighting","content":"pub fn fe_diffuse_lighting(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feDiffuseLighting&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDiffuseLighting)\nSynonyms:\nsprocket/html/svg/elements.fe_diffuse_lighting\nsprocket/html/svg/elements fe_diffuse_lighting","url":"sprocket/html/svg/elements.html#fe_diffuse_lighting"},{"doc":"sprocket/html/svg/elements","title":"fe_displacement_map","content":"pub fn fe_displacement_map(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feDisplacementMap&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDisplacementMap)\nSynonyms:\nsprocket/html/svg/elements.fe_displacement_map\nsprocket/html/svg/elements fe_displacement_map","url":"sprocket/html/svg/elements.html#fe_displacement_map"},{"doc":"sprocket/html/svg/elements","title":"fe_distant_light","content":"pub fn fe_distant_light(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feDistantLight&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDistantLight)\nSynonyms:\nsprocket/html/svg/elements.fe_distant_light\nsprocket/html/svg/elements fe_distant_light","url":"sprocket/html/svg/elements.html#fe_distant_light"},{"doc":"sprocket/html/svg/elements","title":"fe_drop_shadow","content":"pub fn fe_drop_shadow(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feDropShadow&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDropShadow)\nSynonyms:\nsprocket/html/svg/elements.fe_drop_shadow\nsprocket/html/svg/elements fe_drop_shadow","url":"sprocket/html/svg/elements.html#fe_drop_shadow"},{"doc":"sprocket/html/svg/elements","title":"fe_flood","content":"pub fn fe_flood(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feFlood&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFlood)\nSynonyms:\nsprocket/html/svg/elements.fe_flood\nsprocket/html/svg/elements fe_flood","url":"sprocket/html/svg/elements.html#fe_flood"},{"doc":"sprocket/html/svg/elements","title":"fe_func_a","content":"pub fn fe_func_a(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feFuncA&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncA)\nSynonyms:\nsprocket/html/svg/elements.fe_func_a\nsprocket/html/svg/elements fe_func_a","url":"sprocket/html/svg/elements.html#fe_func_a"},{"doc":"sprocket/html/svg/elements","title":"fe_func_b","content":"pub fn fe_func_b(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feFuncB&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncB)\nSynonyms:\nsprocket/html/svg/elements.fe_func_b\nsprocket/html/svg/elements fe_func_b","url":"sprocket/html/svg/elements.html#fe_func_b"},{"doc":"sprocket/html/svg/elements","title":"fe_func_g","content":"pub fn fe_func_g(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feFuncG&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncG)\nSynonyms:\nsprocket/html/svg/elements.fe_func_g\nsprocket/html/svg/elements fe_func_g","url":"sprocket/html/svg/elements.html#fe_func_g"},{"doc":"sprocket/html/svg/elements","title":"fe_func_r","content":"pub fn fe_func_r(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feFuncR&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncR)\nSynonyms:\nsprocket/html/svg/elements.fe_func_r\nsprocket/html/svg/elements fe_func_r","url":"sprocket/html/svg/elements.html#fe_func_r"},{"doc":"sprocket/html/svg/elements","title":"fe_gaussian_blur","content":"pub fn fe_gaussian_blur(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feGaussianBlur&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feGaussianBlur)\nSynonyms:\nsprocket/html/svg/elements.fe_gaussian_blur\nsprocket/html/svg/elements fe_gaussian_blur","url":"sprocket/html/svg/elements.html#fe_gaussian_blur"},{"doc":"sprocket/html/svg/elements","title":"fe_image","content":"pub fn fe_image(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feImage&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feImage)\nSynonyms:\nsprocket/html/svg/elements.fe_image\nsprocket/html/svg/elements fe_image","url":"sprocket/html/svg/elements.html#fe_image"},{"doc":"sprocket/html/svg/elements","title":"fe_merge","content":"pub fn fe_merge(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feMerge&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMerge)\nSynonyms:\nsprocket/html/svg/elements.fe_merge\nsprocket/html/svg/elements fe_merge","url":"sprocket/html/svg/elements.html#fe_merge"},{"doc":"sprocket/html/svg/elements","title":"fe_merge_node","content":"pub fn fe_merge_node(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feMergeNode&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMergeNode)\nSynonyms:\nsprocket/html/svg/elements.fe_merge_node\nsprocket/html/svg/elements fe_merge_node","url":"sprocket/html/svg/elements.html#fe_merge_node"},{"doc":"sprocket/html/svg/elements","title":"fe_morphology","content":"pub fn fe_morphology(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feMorphology&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMorphology)\nSynonyms:\nsprocket/html/svg/elements.fe_morphology\nsprocket/html/svg/elements fe_morphology","url":"sprocket/html/svg/elements.html#fe_morphology"},{"doc":"sprocket/html/svg/elements","title":"fe_offset","content":"pub fn fe_offset(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feOffset&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feOffset)\nSynonyms:\nsprocket/html/svg/elements.fe_offset\nsprocket/html/svg/elements fe_offset","url":"sprocket/html/svg/elements.html#fe_offset"},{"doc":"sprocket/html/svg/elements","title":"fe_point_light","content":"pub fn fe_point_light(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;fePointLight&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/fePointLight)\nSynonyms:\nsprocket/html/svg/elements.fe_point_light\nsprocket/html/svg/elements fe_point_light","url":"sprocket/html/svg/elements.html#fe_point_light"},{"doc":"sprocket/html/svg/elements","title":"fe_specular_lighting","content":"pub fn fe_specular_lighting(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feSpecularLighting&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpecularLighting)\nSynonyms:\nsprocket/html/svg/elements.fe_specular_lighting\nsprocket/html/svg/elements fe_specular_lighting","url":"sprocket/html/svg/elements.html#fe_specular_lighting"},{"doc":"sprocket/html/svg/elements","title":"fe_spot_light","content":"pub fn fe_spot_light(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feSpotLight&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpotLight)\nSynonyms:\nsprocket/html/svg/elements.fe_spot_light\nsprocket/html/svg/elements fe_spot_light","url":"sprocket/html/svg/elements.html#fe_spot_light"},{"doc":"sprocket/html/svg/elements","title":"fe_tile","content":"pub fn fe_tile(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feTile&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTile)\nSynonyms:\nsprocket/html/svg/elements.fe_tile\nsprocket/html/svg/elements fe_tile","url":"sprocket/html/svg/elements.html#fe_tile"},{"doc":"sprocket/html/svg/elements","title":"fe_turbulence","content":"pub fn fe_turbulence(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;feTurbulence&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTurbulence)\nSynonyms:\nsprocket/html/svg/elements.fe_turbulence\nsprocket/html/svg/elements fe_turbulence","url":"sprocket/html/svg/elements.html#fe_turbulence"},{"doc":"sprocket/html/svg/elements","title":"filter","content":"pub fn filter(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;filter&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/filter)\nSynonyms:\nsprocket/html/svg/elements.filter\nsprocket/html/svg/elements filter","url":"sprocket/html/svg/elements.html#filter"},{"doc":"sprocket/html/svg/elements","title":"foreign_object","content":"pub fn foreign_object(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;foreignObject&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/foreignObject)\nSynonyms:\nsprocket/html/svg/elements.foreign_object\nsprocket/html/svg/elements foreign_object","url":"sprocket/html/svg/elements.html#foreign_object"},{"doc":"sprocket/html/svg/elements","title":"g","content":"pub fn g(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;g&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/g)\nSynonyms:\nsprocket/html/svg/elements.g\nsprocket/html/svg/elements g","url":"sprocket/html/svg/elements.html#g"},{"doc":"sprocket/html/svg/elements","title":"hatch","content":"pub fn hatch(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;hatch&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/hatch)\nSynonyms:\nsprocket/html/svg/elements.hatch\nsprocket/html/svg/elements hatch","url":"sprocket/html/svg/elements.html#hatch"},{"doc":"sprocket/html/svg/elements","title":"hatchpath","content":"pub fn hatchpath(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;hatchpath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/hatchpath)\nSynonyms:\nsprocket/html/svg/elements.hatchpath\nsprocket/html/svg/elements hatchpath","url":"sprocket/html/svg/elements.html#hatchpath"},{"doc":"sprocket/html/svg/elements","title":"image","content":"pub fn image(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;image&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/image)\nSynonyms:\nsprocket/html/svg/elements.image\nsprocket/html/svg/elements image","url":"sprocket/html/svg/elements.html#image"},{"doc":"sprocket/html/svg/elements","title":"line","content":"pub fn line(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;line&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/line)\nSynonyms:\nsprocket/html/svg/elements.line\nsprocket/html/svg/elements line","url":"sprocket/html/svg/elements.html#line"},{"doc":"sprocket/html/svg/elements","title":"linear_gradient","content":"pub fn linear_gradient(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;linearGradient&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/linearGradient)\nSynonyms:\nsprocket/html/svg/elements.linear_gradient\nsprocket/html/svg/elements linear_gradient","url":"sprocket/html/svg/elements.html#linear_gradient"},{"doc":"sprocket/html/svg/elements","title":"marker","content":"pub fn marker(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;marker&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/marker)\nSynonyms:\nsprocket/html/svg/elements.marker\nsprocket/html/svg/elements marker","url":"sprocket/html/svg/elements.html#marker"},{"doc":"sprocket/html/svg/elements","title":"mask","content":"pub fn mask(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;mask&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mask)\nSynonyms:\nsprocket/html/svg/elements.mask\nsprocket/html/svg/elements mask","url":"sprocket/html/svg/elements.html#mask"},{"doc":"sprocket/html/svg/elements","title":"metadata","content":"pub fn metadata(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;metadata&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/metadata)\nSynonyms:\nsprocket/html/svg/elements.metadata\nsprocket/html/svg/elements metadata","url":"sprocket/html/svg/elements.html#metadata"},{"doc":"sprocket/html/svg/elements","title":"mpath","content":"pub fn mpath(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;mpath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mpath)\nSynonyms:\nsprocket/html/svg/elements.mpath\nsprocket/html/svg/elements mpath","url":"sprocket/html/svg/elements.html#mpath"},{"doc":"sprocket/html/svg/elements","title":"path","content":"pub fn path(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;path&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/path)\nSynonyms:\nsprocket/html/svg/elements.path\nsprocket/html/svg/elements path","url":"sprocket/html/svg/elements.html#path"},{"doc":"sprocket/html/svg/elements","title":"pattern","content":"pub fn pattern(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;pattern&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/pattern)\nSynonyms:\nsprocket/html/svg/elements.pattern\nsprocket/html/svg/elements pattern","url":"sprocket/html/svg/elements.html#pattern"},{"doc":"sprocket/html/svg/elements","title":"polygon","content":"pub fn polygon(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;polygon&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polygon)\nSynonyms:\nsprocket/html/svg/elements.polygon\nsprocket/html/svg/elements polygon","url":"sprocket/html/svg/elements.html#polygon"},{"doc":"sprocket/html/svg/elements","title":"polyline","content":"pub fn polyline(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;polyline&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polyline)\nSynonyms:\nsprocket/html/svg/elements.polyline\nsprocket/html/svg/elements polyline","url":"sprocket/html/svg/elements.html#polyline"},{"doc":"sprocket/html/svg/elements","title":"radial_gradient","content":"pub fn radial_gradient(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;radialGradient&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/radialGradient)\nSynonyms:\nsprocket/html/svg/elements.radial_gradient\nsprocket/html/svg/elements radial_gradient","url":"sprocket/html/svg/elements.html#radial_gradient"},{"doc":"sprocket/html/svg/elements","title":"rect","content":"pub fn rect(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;rect&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/rect)\nSynonyms:\nsprocket/html/svg/elements.rect\nsprocket/html/svg/elements rect","url":"sprocket/html/svg/elements.html#rect"},{"doc":"sprocket/html/svg/elements","title":"script","content":"pub fn script(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;script&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/script)\nSynonyms:\nsprocket/html/svg/elements.script\nsprocket/html/svg/elements script","url":"sprocket/html/svg/elements.html#script"},{"doc":"sprocket/html/svg/elements","title":"set","content":"pub fn set(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;set&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/set)\nSynonyms:\nsprocket/html/svg/elements.set\nsprocket/html/svg/elements set","url":"sprocket/html/svg/elements.html#set"},{"doc":"sprocket/html/svg/elements","title":"stop","content":"pub fn stop(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;stop&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/stop)\nSynonyms:\nsprocket/html/svg/elements.stop\nsprocket/html/svg/elements stop","url":"sprocket/html/svg/elements.html#stop"},{"doc":"sprocket/html/svg/elements","title":"style","content":"pub fn style(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;style&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/style)\nSynonyms:\nsprocket/html/svg/elements.style\nsprocket/html/svg/elements style","url":"sprocket/html/svg/elements.html#style"},{"doc":"sprocket/html/svg/elements","title":"svg","content":"pub fn svg(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;svg&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/svg)\nSynonyms:\nsprocket/html/svg/elements.svg\nsprocket/html/svg/elements svg","url":"sprocket/html/svg/elements.html#svg"},{"doc":"sprocket/html/svg/elements","title":"switch","content":"pub fn switch(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;switch&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/switch)\nSynonyms:\nsprocket/html/svg/elements.switch\nsprocket/html/svg/elements switch","url":"sprocket/html/svg/elements.html#switch"},{"doc":"sprocket/html/svg/elements","title":"symbol","content":"pub fn symbol(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;symbol&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/symbol)\nSynonyms:\nsprocket/html/svg/elements.symbol\nsprocket/html/svg/elements symbol","url":"sprocket/html/svg/elements.html#symbol"},{"doc":"sprocket/html/svg/elements","title":"text","content":"pub fn text(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;text&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/text)\nSynonyms:\nsprocket/html/svg/elements.text\nsprocket/html/svg/elements text","url":"sprocket/html/svg/elements.html#text"},{"doc":"sprocket/html/svg/elements","title":"text_path","content":"pub fn text_path(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;textPath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/textPath)\nSynonyms:\nsprocket/html/svg/elements.text_path\nsprocket/html/svg/elements text_path","url":"sprocket/html/svg/elements.html#text_path"},{"doc":"sprocket/html/svg/elements","title":"title","content":"pub fn title(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;title&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title)\nSynonyms:\nsprocket/html/svg/elements.title\nsprocket/html/svg/elements title","url":"sprocket/html/svg/elements.html#title"},{"doc":"sprocket/html/svg/elements","title":"tspan","content":"pub fn tspan(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;tspan&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/tspan)\nSynonyms:\nsprocket/html/svg/elements.tspan\nsprocket/html/svg/elements tspan","url":"sprocket/html/svg/elements.html#tspan"},{"doc":"sprocket/html/svg/elements","title":"use_","content":"pub fn use_(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;use&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/use)\nSynonyms:\nsprocket/html/svg/elements.use_\nsprocket/html/svg/elements use_","url":"sprocket/html/svg/elements.html#use_"},{"doc":"sprocket/html/svg/elements","title":"view","content":"pub fn view(\n  attrs: List(Attribute),\n  children: List(Element),\n) -&gt; Element\n The [SVG `&lt;view&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/view)\nSynonyms:\nsprocket/html/svg/elements.view\nsprocket/html/svg/elements view","url":"sprocket/html/svg/elements.html#view"},{"doc":"sprocket/html/svg/elements","title":"sprocket/html/svg/elements","content":"","url":"sprocket/html/svg/elements.html"},{"doc":"sprocket/renderers/json","title":"json_renderer","content":"pub fn json_renderer() -&gt; Renderer(Json)\n\nSynonyms:\nsprocket/renderers/json.json_renderer\nsprocket/renderers/json json_renderer","url":"sprocket/renderers/json.html#json_renderer"},{"doc":"sprocket/renderers/json","title":"sprocket/renderers/json","content":"","url":"sprocket/renderers/json.html"},{"doc":"sprocket/renderers/html","title":"html_renderer","content":"pub fn html_renderer() -&gt; Renderer(String)\n\nSynonyms:\nsprocket/renderers/html.html_renderer\nsprocket/renderers/html html_renderer","url":"sprocket/renderers/html.html#html_renderer"},{"doc":"sprocket/renderers/html","title":"sprocket/renderers/html","content":"","url":"sprocket/renderers/html.html"},{"doc":"sprocket/test_helpers","title":"Event","content":"pub type Event {\n  ClickEvent\n}\n\nClickEvent\n\n\nSynonyms:\nsprocket/test_helpers.Event\nsprocket/test_helpers Event","url":"sprocket/test_helpers.html#Event"},{"doc":"sprocket/test_helpers","title":"connect","content":"pub fn connect(view: Element) -&gt; Subject(Message)\n\nSynonyms:\nsprocket/test_helpers.connect\nsprocket/test_helpers connect","url":"sprocket/test_helpers.html#connect"},{"doc":"sprocket/test_helpers","title":"render_event","content":"pub fn render_event(\n  spkt: Subject(Message),\n  event: Event,\n  html_id: String,\n) -&gt; Subject(Message)\n\nSynonyms:\nsprocket/test_helpers.render_event\nsprocket/test_helpers render_event","url":"sprocket/test_helpers.html#render_event"},{"doc":"sprocket/test_helpers","title":"render_html","content":"pub fn render_html(\n  spkt: Subject(Message),\n) -&gt; #(Subject(Message), String)\n\nSynonyms:\nsprocket/test_helpers.render_html\nsprocket/test_helpers render_html","url":"sprocket/test_helpers.html#render_html"},{"doc":"sprocket/test_helpers","title":"sprocket/test_helpers","content":"","url":"sprocket/test_helpers.html"},{"doc":"sprocket/hooks","title":"callback","content":"pub fn callback(\n  ctx: Context,\n  callback_fn: fn() -&gt; Nil,\n  trigger: HookTrigger,\n  cb: fn(Context, fn() -&gt; Nil) -&gt; #(a, Element),\n) -&gt; #(a, Element)\n Callback Hook\n -------------\n Creates a callback hook that will return a cached version of a given callback\n function and only recompute the callback as specified by the trigger.\n \n This hook is useful for when a component needs to use a callback function that\n is referenced as a dependency by another hook, such as an effect hook.\nSynonyms:\nsprocket/hooks.callback\nsprocket/hooks callback","url":"sprocket/hooks.html#callback"},{"doc":"sprocket/hooks","title":"client","content":"pub fn client(\n  ctx: Context,\n  name: String,\n  handle_event: Option(\n    fn(\n      String,\n      Option(Dynamic),\n      fn(String, Option(String)) -&gt; Result(Nil, Nil),\n    ) -&gt; Nil,\n  ),\n  cb: fn(\n    Context,\n    fn() -&gt; Attribute,\n    fn(String, Option(String)) -&gt; Result(Nil, Nil),\n  ) -&gt; #(Context, Element),\n) -&gt; #(Context, Element)\n Client Hook\n -----------\n Creates a client hook that can be used to facilitate communication with a client\n (such as a web browser). The client hook functionality is defined by the client\n and is typically used to send or receive messages to/from the client.\nSynonyms:\nsprocket/hooks.client\nsprocket/hooks client","url":"sprocket/hooks.html#client"},{"doc":"sprocket/hooks","title":"effect","content":"pub fn effect(\n  ctx: Context,\n  effect_fn: fn() -&gt; Option(fn() -&gt; Nil),\n  trigger: HookTrigger,\n  cb: fn(Context) -&gt; #(Context, Element),\n) -&gt; #(Context, Element)\n Effect Hook\n -----------\n Creates an effect hook that will run the given effect function when the hook is\n triggered. The effect function is memoized and recomputed based on the trigger type.\nSynonyms:\nsprocket/hooks.effect\nsprocket/hooks effect","url":"sprocket/hooks.html#effect"},{"doc":"sprocket/hooks","title":"handler","content":"pub fn handler(\n  ctx: Context,\n  handler_fn: fn(Option(CallbackParam)) -&gt; Nil,\n  cb: fn(Context, IdentifiableHandler) -&gt; #(a, Element),\n) -&gt; #(a, Element)\n Handler Hook\n -------------\n Creates a handler callback that can be triggered from DOM event attributes. The callback\n function will be called with the event payload. This hook ensures that the handler\n identifier remains stable preventing unnecessary id changes across renders.\nSynonyms:\nsprocket/hooks.handler\nsprocket/hooks handler","url":"sprocket/hooks.html#handler"},{"doc":"sprocket/hooks","title":"memo","content":"pub fn memo(\n  ctx: Context,\n  memo_fn: fn() -&gt; a,\n  trigger: HookTrigger,\n  cb: fn(Context, a) -&gt; #(Context, Element),\n) -&gt; #(Context, Element)\n Memo Hook\n ---------\n Creates a memo hook that can be used to memoize the result of a function. The memo\n hook will return the result of the function and will only recompute the result as\n specified by the trigger.\n \n This hook is useful for optimizing performance by memoizing the result of an\n expensive function between renders.\nSynonyms:\nsprocket/hooks.memo\nsprocket/hooks memo","url":"sprocket/hooks.html#memo"},{"doc":"sprocket/hooks","title":"provider","content":"pub fn provider(\n  ctx: Context,\n  key: String,\n  cb: fn(Context, Option(a)) -&gt; #(Context, Element),\n) -&gt; #(Context, Element)\n Provider Hook\n ------------\n Creates a provider hook that allows a component to access data from a parent or ancestor component.\n The provider hook will return the current value provided from an ancestor with the given key. The\n ancestor provides the value by using the `provider` element from the `sprocket/context` module.\n \n This hook is conceptually the same as the `useContext` hook in React.\nSynonyms:\nsprocket/hooks.provider\nsprocket/hooks provider","url":"sprocket/hooks.html#provider"},{"doc":"sprocket/hooks","title":"reducer","content":"pub fn reducer(\n  ctx: Context,\n  initial: a,\n  reducer: fn(a, b) -&gt; a,\n  cb: fn(Context, a, fn(b) -&gt; Nil) -&gt; #(Context, Element),\n) -&gt; #(Context, Element)\n Reducer Hook\n ------------\n Creates a reducer hook that can be used to manage state. The reducer hook will\n return the current state of the reducer and a dispatch function that can be used\n to update the reducer&#39;s state. Dispatching a message to the reducer will result\n in a re-render of the component.\nSynonyms:\nsprocket/hooks.reducer\nsprocket/hooks reducer","url":"sprocket/hooks.html#reducer"},{"doc":"sprocket/hooks","title":"state","content":"pub fn state(\n  ctx: Context,\n  initial: a,\n  cb: fn(Context, a, fn(a) -&gt; Nil) -&gt; #(Context, Element),\n) -&gt; #(Context, Element)\n State Hook\n ----------\n Creates a state hook that can be used to manage state. The state hook will return\n the current state and a setter function that can be used to update the state. Setting\n the state will result in a re-render of the component.\nSynonyms:\nsprocket/hooks.state\nsprocket/hooks state","url":"sprocket/hooks.html#state"},{"doc":"sprocket/hooks","title":"sprocket/hooks","content":"","url":"sprocket/hooks.html"},{"doc":"sprocket/html/attributes","title":"accept","content":"pub fn accept(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.accept\nsprocket/html/attributes accept","url":"sprocket/html/attributes.html#accept"},{"doc":"sprocket/html/attributes","title":"accept_charset","content":"pub fn accept_charset(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.accept_charset\nsprocket/html/attributes accept_charset","url":"sprocket/html/attributes.html#accept_charset"},{"doc":"sprocket/html/attributes","title":"action","content":"pub fn action(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.action\nsprocket/html/attributes action","url":"sprocket/html/attributes.html#action"},{"doc":"sprocket/html/attributes","title":"alt","content":"pub fn alt(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.alt\nsprocket/html/attributes alt","url":"sprocket/html/attributes.html#alt"},{"doc":"sprocket/html/attributes","title":"async","content":"pub fn async() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.async\nsprocket/html/attributes async","url":"sprocket/html/attributes.html#async"},{"doc":"sprocket/html/attributes","title":"attribute","content":"pub fn attribute(name: String, value: a) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.attribute\nsprocket/html/attributes attribute","url":"sprocket/html/attributes.html#attribute"},{"doc":"sprocket/html/attributes","title":"autocapitalize","content":"pub fn autocapitalize(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autocapitalize\nsprocket/html/attributes autocapitalize","url":"sprocket/html/attributes.html#autocapitalize"},{"doc":"sprocket/html/attributes","title":"autocomplete","content":"pub fn autocomplete(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autocomplete\nsprocket/html/attributes autocomplete","url":"sprocket/html/attributes.html#autocomplete"},{"doc":"sprocket/html/attributes","title":"autofocus","content":"pub fn autofocus() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autofocus\nsprocket/html/attributes autofocus","url":"sprocket/html/attributes.html#autofocus"},{"doc":"sprocket/html/attributes","title":"autoplay","content":"pub fn autoplay() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autoplay\nsprocket/html/attributes autoplay","url":"sprocket/html/attributes.html#autoplay"},{"doc":"sprocket/html/attributes","title":"capture","content":"pub fn capture(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.capture\nsprocket/html/attributes capture","url":"sprocket/html/attributes.html#capture"},{"doc":"sprocket/html/attributes","title":"charset","content":"pub fn charset(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.charset\nsprocket/html/attributes charset","url":"sprocket/html/attributes.html#charset"},{"doc":"sprocket/html/attributes","title":"checked","content":"pub fn checked() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.checked\nsprocket/html/attributes checked","url":"sprocket/html/attributes.html#checked"},{"doc":"sprocket/html/attributes","title":"cite","content":"pub fn cite(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.cite\nsprocket/html/attributes cite","url":"sprocket/html/attributes.html#cite"},{"doc":"sprocket/html/attributes","title":"class","content":"pub fn class(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.class\nsprocket/html/attributes class","url":"sprocket/html/attributes.html#class"},{"doc":"sprocket/html/attributes","title":"classes","content":"pub fn classes(value: List(Option(String))) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.classes\nsprocket/html/attributes classes","url":"sprocket/html/attributes.html#classes"},{"doc":"sprocket/html/attributes","title":"client_hook","content":"pub fn client_hook(id: Unique, name: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.client_hook\nsprocket/html/attributes client_hook","url":"sprocket/html/attributes.html#client_hook"},{"doc":"sprocket/html/attributes","title":"content","content":"pub fn content(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.content\nsprocket/html/attributes content","url":"sprocket/html/attributes.html#content"},{"doc":"sprocket/html/attributes","title":"contenteditable","content":"pub fn contenteditable() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.contenteditable\nsprocket/html/attributes contenteditable","url":"sprocket/html/attributes.html#contenteditable"},{"doc":"sprocket/html/attributes","title":"crossorigin","content":"pub fn crossorigin(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.crossorigin\nsprocket/html/attributes crossorigin","url":"sprocket/html/attributes.html#crossorigin"},{"doc":"sprocket/html/attributes","title":"defer","content":"pub fn defer() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.defer\nsprocket/html/attributes defer","url":"sprocket/html/attributes.html#defer"},{"doc":"sprocket/html/attributes","title":"disabled","content":"pub fn disabled() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.disabled\nsprocket/html/attributes disabled","url":"sprocket/html/attributes.html#disabled"},{"doc":"sprocket/html/attributes","title":"draggable","content":"pub fn draggable() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.draggable\nsprocket/html/attributes draggable","url":"sprocket/html/attributes.html#draggable"},{"doc":"sprocket/html/attributes","title":"event","content":"pub fn event(\n  name: String,\n  handler: IdentifiableHandler,\n) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.event\nsprocket/html/attributes event","url":"sprocket/html/attributes.html#event"},{"doc":"sprocket/html/attributes","title":"for","content":"pub fn for(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.for\nsprocket/html/attributes for","url":"sprocket/html/attributes.html#for"},{"doc":"sprocket/html/attributes","title":"formaction","content":"pub fn formaction(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.formaction\nsprocket/html/attributes formaction","url":"sprocket/html/attributes.html#formaction"},{"doc":"sprocket/html/attributes","title":"height","content":"pub fn height(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.height\nsprocket/html/attributes height","url":"sprocket/html/attributes.html#height"},{"doc":"sprocket/html/attributes","title":"href","content":"pub fn href(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.href\nsprocket/html/attributes href","url":"sprocket/html/attributes.html#href"},{"doc":"sprocket/html/attributes","title":"http_equiv","content":"pub fn http_equiv(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.http_equiv\nsprocket/html/attributes http_equiv","url":"sprocket/html/attributes.html#http_equiv"},{"doc":"sprocket/html/attributes","title":"id","content":"pub fn id(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.id\nsprocket/html/attributes id","url":"sprocket/html/attributes.html#id"},{"doc":"sprocket/html/attributes","title":"input_type","content":"pub fn input_type(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.input_type\nsprocket/html/attributes input_type","url":"sprocket/html/attributes.html#input_type"},{"doc":"sprocket/html/attributes","title":"integrity","content":"pub fn integrity(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.integrity\nsprocket/html/attributes integrity","url":"sprocket/html/attributes.html#integrity"},{"doc":"sprocket/html/attributes","title":"lang","content":"pub fn lang(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.lang\nsprocket/html/attributes lang","url":"sprocket/html/attributes.html#lang"},{"doc":"sprocket/html/attributes","title":"loop","content":"pub fn loop() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.loop\nsprocket/html/attributes loop","url":"sprocket/html/attributes.html#loop"},{"doc":"sprocket/html/attributes","title":"media","content":"pub fn media(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.media\nsprocket/html/attributes media","url":"sprocket/html/attributes.html#media"},{"doc":"sprocket/html/attributes","title":"method","content":"pub fn method(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.method\nsprocket/html/attributes method","url":"sprocket/html/attributes.html#method"},{"doc":"sprocket/html/attributes","title":"name","content":"pub fn name(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.name\nsprocket/html/attributes name","url":"sprocket/html/attributes.html#name"},{"doc":"sprocket/html/attributes","title":"on_change","content":"pub fn on_change(handler: IdentifiableHandler) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_change\nsprocket/html/attributes on_change","url":"sprocket/html/attributes.html#on_change"},{"doc":"sprocket/html/attributes","title":"on_click","content":"pub fn on_click(handler: IdentifiableHandler) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_click\nsprocket/html/attributes on_click","url":"sprocket/html/attributes.html#on_click"},{"doc":"sprocket/html/attributes","title":"on_doubleclick","content":"pub fn on_doubleclick(handler: IdentifiableHandler) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_doubleclick\nsprocket/html/attributes on_doubleclick","url":"sprocket/html/attributes.html#on_doubleclick"},{"doc":"sprocket/html/attributes","title":"on_input","content":"pub fn on_input(handler: IdentifiableHandler) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_input\nsprocket/html/attributes on_input","url":"sprocket/html/attributes.html#on_input"},{"doc":"sprocket/html/attributes","title":"placeholder","content":"pub fn placeholder(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.placeholder\nsprocket/html/attributes placeholder","url":"sprocket/html/attributes.html#placeholder"},{"doc":"sprocket/html/attributes","title":"preload","content":"pub fn preload() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.preload\nsprocket/html/attributes preload","url":"sprocket/html/attributes.html#preload"},{"doc":"sprocket/html/attributes","title":"property","content":"pub fn property(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.property\nsprocket/html/attributes property","url":"sprocket/html/attributes.html#property"},{"doc":"sprocket/html/attributes","title":"readonly","content":"pub fn readonly() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.readonly\nsprocket/html/attributes readonly","url":"sprocket/html/attributes.html#readonly"},{"doc":"sprocket/html/attributes","title":"referrerpolicy","content":"pub fn referrerpolicy(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.referrerpolicy\nsprocket/html/attributes referrerpolicy","url":"sprocket/html/attributes.html#referrerpolicy"},{"doc":"sprocket/html/attributes","title":"rel","content":"pub fn rel(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.rel\nsprocket/html/attributes rel","url":"sprocket/html/attributes.html#rel"},{"doc":"sprocket/html/attributes","title":"role","content":"pub fn role(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.role\nsprocket/html/attributes role","url":"sprocket/html/attributes.html#role"},{"doc":"sprocket/html/attributes","title":"selected","content":"pub fn selected() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.selected\nsprocket/html/attributes selected","url":"sprocket/html/attributes.html#selected"},{"doc":"sprocket/html/attributes","title":"src","content":"pub fn src(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.src\nsprocket/html/attributes src","url":"sprocket/html/attributes.html#src"},{"doc":"sprocket/html/attributes","title":"style","content":"pub fn style(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.style\nsprocket/html/attributes style","url":"sprocket/html/attributes.html#style"},{"doc":"sprocket/html/attributes","title":"tabindex","content":"pub fn tabindex(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.tabindex\nsprocket/html/attributes tabindex","url":"sprocket/html/attributes.html#tabindex"},{"doc":"sprocket/html/attributes","title":"target","content":"pub fn target(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.target\nsprocket/html/attributes target","url":"sprocket/html/attributes.html#target"},{"doc":"sprocket/html/attributes","title":"title","content":"pub fn title(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.title\nsprocket/html/attributes title","url":"sprocket/html/attributes.html#title"},{"doc":"sprocket/html/attributes","title":"value","content":"pub fn value(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.value\nsprocket/html/attributes value","url":"sprocket/html/attributes.html#value"},{"doc":"sprocket/html/attributes","title":"width","content":"pub fn width(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.width\nsprocket/html/attributes width","url":"sprocket/html/attributes.html#width"},{"doc":"sprocket/html/attributes","title":"xmlns","content":"pub fn xmlns(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.xmlns\nsprocket/html/attributes xmlns","url":"sprocket/html/attributes.html#xmlns"},{"doc":"sprocket/html/attributes","title":"xmlns_xlink","content":"pub fn xmlns_xlink(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.xmlns_xlink\nsprocket/html/attributes xmlns_xlink","url":"sprocket/html/attributes.html#xmlns_xlink"},{"doc":"sprocket/html/attributes","title":"sprocket/html/attributes","content":"","url":"sprocket/html/attributes.html"},{"doc":"sprocket/renderers/identity","title":"identity_renderer","content":"pub fn identity_renderer() -&gt; Renderer(ReconciledElement)\n\nSynonyms:\nsprocket/renderers/identity.identity_renderer\nsprocket/renderers/identity identity_renderer","url":"sprocket/renderers/identity.html#identity_renderer"},{"doc":"sprocket/renderers/identity","title":"sprocket/renderers/identity","content":"","url":"sprocket/renderers/identity.html"},{"doc":"sprocket/html/svg/attributes","title":"accent_height","content":"pub fn accent_height(value: String) -&gt; Attribute\n The [SVG `accent-height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/accent-height)\nSynonyms:\nsprocket/html/svg/attributes.accent_height\nsprocket/html/svg/attributes accent_height","url":"sprocket/html/svg/attributes.html#accent_height"},{"doc":"sprocket/html/svg/attributes","title":"accumulate","content":"pub fn accumulate(value: String) -&gt; Attribute\n The [SVG `accumulate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/accumulate)\nSynonyms:\nsprocket/html/svg/attributes.accumulate\nsprocket/html/svg/attributes accumulate","url":"sprocket/html/svg/attributes.html#accumulate"},{"doc":"sprocket/html/svg/attributes","title":"additive","content":"pub fn additive(value: String) -&gt; Attribute\n The [SVG `additive` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/additive)\nSynonyms:\nsprocket/html/svg/attributes.additive\nsprocket/html/svg/attributes additive","url":"sprocket/html/svg/attributes.html#additive"},{"doc":"sprocket/html/svg/attributes","title":"alignment_baseline","content":"pub fn alignment_baseline(value: String) -&gt; Attribute\n The [SVG `alignment-baseline` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/alignment-baseline)\nSynonyms:\nsprocket/html/svg/attributes.alignment_baseline\nsprocket/html/svg/attributes alignment_baseline","url":"sprocket/html/svg/attributes.html#alignment_baseline"},{"doc":"sprocket/html/svg/attributes","title":"alphabetic","content":"pub fn alphabetic(value: String) -&gt; Attribute\n The [SVG `alphabetic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/alphabetic)\nSynonyms:\nsprocket/html/svg/attributes.alphabetic\nsprocket/html/svg/attributes alphabetic","url":"sprocket/html/svg/attributes.html#alphabetic"},{"doc":"sprocket/html/svg/attributes","title":"amplitude","content":"pub fn amplitude(value: String) -&gt; Attribute\n The [SVG `amplitude` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/amplitude)\nSynonyms:\nsprocket/html/svg/attributes.amplitude\nsprocket/html/svg/attributes amplitude","url":"sprocket/html/svg/attributes.html#amplitude"},{"doc":"sprocket/html/svg/attributes","title":"arabic_form","content":"pub fn arabic_form(value: String) -&gt; Attribute\n The [SVG `arabic-form` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/arabic-form)\nSynonyms:\nsprocket/html/svg/attributes.arabic_form\nsprocket/html/svg/attributes arabic_form","url":"sprocket/html/svg/attributes.html#arabic_form"},{"doc":"sprocket/html/svg/attributes","title":"ascent","content":"pub fn ascent(value: String) -&gt; Attribute\n The [SVG `ascent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ascent)\nSynonyms:\nsprocket/html/svg/attributes.ascent\nsprocket/html/svg/attributes ascent","url":"sprocket/html/svg/attributes.html#ascent"},{"doc":"sprocket/html/svg/attributes","title":"attribute_name","content":"pub fn attribute_name(value: String) -&gt; Attribute\n The [SVG `attributeName` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/attributeName)\nSynonyms:\nsprocket/html/svg/attributes.attribute_name\nsprocket/html/svg/attributes attribute_name","url":"sprocket/html/svg/attributes.html#attribute_name"},{"doc":"sprocket/html/svg/attributes","title":"attribute_type","content":"pub fn attribute_type(value: String) -&gt; Attribute\n The [SVG `attributeType` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/attributeType)\nSynonyms:\nsprocket/html/svg/attributes.attribute_type\nsprocket/html/svg/attributes attribute_type","url":"sprocket/html/svg/attributes.html#attribute_type"},{"doc":"sprocket/html/svg/attributes","title":"azimuth","content":"pub fn azimuth(value: String) -&gt; Attribute\n The [SVG `azimuth` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/azimuth)\nSynonyms:\nsprocket/html/svg/attributes.azimuth\nsprocket/html/svg/attributes azimuth","url":"sprocket/html/svg/attributes.html#azimuth"},{"doc":"sprocket/html/svg/attributes","title":"base_frequency","content":"pub fn base_frequency(value: String) -&gt; Attribute\n The [SVG `baseFrequency` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/baseFrequency)\nSynonyms:\nsprocket/html/svg/attributes.base_frequency\nsprocket/html/svg/attributes base_frequency","url":"sprocket/html/svg/attributes.html#base_frequency"},{"doc":"sprocket/html/svg/attributes","title":"base_profile","content":"pub fn base_profile(value: String) -&gt; Attribute\n The [SVG `baseProfile` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/baseProfile)\nSynonyms:\nsprocket/html/svg/attributes.base_profile\nsprocket/html/svg/attributes base_profile","url":"sprocket/html/svg/attributes.html#base_profile"},{"doc":"sprocket/html/svg/attributes","title":"baseline_shift","content":"pub fn baseline_shift(value: String) -&gt; Attribute\n The [SVG `baseline-shift` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/baseline-shift)\nSynonyms:\nsprocket/html/svg/attributes.baseline_shift\nsprocket/html/svg/attributes baseline_shift","url":"sprocket/html/svg/attributes.html#baseline_shift"},{"doc":"sprocket/html/svg/attributes","title":"bbox","content":"pub fn bbox(value: String) -&gt; Attribute\n The [SVG `bbox` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/bbox)\nSynonyms:\nsprocket/html/svg/attributes.bbox\nsprocket/html/svg/attributes bbox","url":"sprocket/html/svg/attributes.html#bbox"},{"doc":"sprocket/html/svg/attributes","title":"begin","content":"pub fn begin(value: String) -&gt; Attribute\n The [SVG `begin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/begin)\nSynonyms:\nsprocket/html/svg/attributes.begin\nsprocket/html/svg/attributes begin","url":"sprocket/html/svg/attributes.html#begin"},{"doc":"sprocket/html/svg/attributes","title":"bias","content":"pub fn bias(value: String) -&gt; Attribute\n The [SVG `bias` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/bias)\nSynonyms:\nsprocket/html/svg/attributes.bias\nsprocket/html/svg/attributes bias","url":"sprocket/html/svg/attributes.html#bias"},{"doc":"sprocket/html/svg/attributes","title":"by","content":"pub fn by(value: String) -&gt; Attribute\n The [SVG `by` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/by)\nSynonyms:\nsprocket/html/svg/attributes.by\nsprocket/html/svg/attributes by","url":"sprocket/html/svg/attributes.html#by"},{"doc":"sprocket/html/svg/attributes","title":"calc_mode","content":"pub fn calc_mode(value: String) -&gt; Attribute\n The [SVG `calcMode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/calcMode)\nSynonyms:\nsprocket/html/svg/attributes.calc_mode\nsprocket/html/svg/attributes calc_mode","url":"sprocket/html/svg/attributes.html#calc_mode"},{"doc":"sprocket/html/svg/attributes","title":"cap_height","content":"pub fn cap_height(value: String) -&gt; Attribute\n The [SVG `cap-height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cap-height)\nSynonyms:\nsprocket/html/svg/attributes.cap_height\nsprocket/html/svg/attributes cap_height","url":"sprocket/html/svg/attributes.html#cap_height"},{"doc":"sprocket/html/svg/attributes","title":"class","content":"pub fn class(value: String) -&gt; Attribute\n The [SVG `class` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/class)\nSynonyms:\nsprocket/html/svg/attributes.class\nsprocket/html/svg/attributes class","url":"sprocket/html/svg/attributes.html#class"},{"doc":"sprocket/html/svg/attributes","title":"clip","content":"pub fn clip(value: String) -&gt; Attribute\n The [SVG `clip` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clip)\nSynonyms:\nsprocket/html/svg/attributes.clip\nsprocket/html/svg/attributes clip","url":"sprocket/html/svg/attributes.html#clip"},{"doc":"sprocket/html/svg/attributes","title":"clip_path","content":"pub fn clip_path(value: String) -&gt; Attribute\n The [SVG `clip-path` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clip-path)\nSynonyms:\nsprocket/html/svg/attributes.clip_path\nsprocket/html/svg/attributes clip_path","url":"sprocket/html/svg/attributes.html#clip_path"},{"doc":"sprocket/html/svg/attributes","title":"clip_path_units","content":"pub fn clip_path_units(value: String) -&gt; Attribute\n The [SVG `clipPathUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clipPathUnits)\nSynonyms:\nsprocket/html/svg/attributes.clip_path_units\nsprocket/html/svg/attributes clip_path_units","url":"sprocket/html/svg/attributes.html#clip_path_units"},{"doc":"sprocket/html/svg/attributes","title":"clip_rule","content":"pub fn clip_rule(value: String) -&gt; Attribute\n The [SVG `clip-rule` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clip-rule)\nSynonyms:\nsprocket/html/svg/attributes.clip_rule\nsprocket/html/svg/attributes clip_rule","url":"sprocket/html/svg/attributes.html#clip_rule"},{"doc":"sprocket/html/svg/attributes","title":"color","content":"pub fn color(value: String) -&gt; Attribute\n The [SVG `color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color)\nSynonyms:\nsprocket/html/svg/attributes.color\nsprocket/html/svg/attributes color","url":"sprocket/html/svg/attributes.html#color"},{"doc":"sprocket/html/svg/attributes","title":"color_interpolation","content":"pub fn color_interpolation(value: String) -&gt; Attribute\n The [SVG `color-interpolation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-interpolation)\nSynonyms:\nsprocket/html/svg/attributes.color_interpolation\nsprocket/html/svg/attributes color_interpolation","url":"sprocket/html/svg/attributes.html#color_interpolation"},{"doc":"sprocket/html/svg/attributes","title":"color_interpolation_filters","content":"pub fn color_interpolation_filters(value: String) -&gt; Attribute\n The [SVG `color-interpolation-filters` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-interpolation-filters)\nSynonyms:\nsprocket/html/svg/attributes.color_interpolation_filters\nsprocket/html/svg/attributes color_interpolation_filters","url":"sprocket/html/svg/attributes.html#color_interpolation_filters"},{"doc":"sprocket/html/svg/attributes","title":"color_profile","content":"pub fn color_profile(value: String) -&gt; Attribute\n The [SVG `color-profile` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-profile)\nSynonyms:\nsprocket/html/svg/attributes.color_profile\nsprocket/html/svg/attributes color_profile","url":"sprocket/html/svg/attributes.html#color_profile"},{"doc":"sprocket/html/svg/attributes","title":"color_rendering","content":"pub fn color_rendering(value: String) -&gt; Attribute\n The [SVG `color-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-rendering)\nSynonyms:\nsprocket/html/svg/attributes.color_rendering\nsprocket/html/svg/attributes color_rendering","url":"sprocket/html/svg/attributes.html#color_rendering"},{"doc":"sprocket/html/svg/attributes","title":"content_script_type","content":"pub fn content_script_type(value: String) -&gt; Attribute\n The [SVG `contentScriptType` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/contentScriptType)\nSynonyms:\nsprocket/html/svg/attributes.content_script_type\nsprocket/html/svg/attributes content_script_type","url":"sprocket/html/svg/attributes.html#content_script_type"},{"doc":"sprocket/html/svg/attributes","title":"content_style_type","content":"pub fn content_style_type(value: String) -&gt; Attribute\n The [SVG `contentStyleType` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/contentStyleType)\nSynonyms:\nsprocket/html/svg/attributes.content_style_type\nsprocket/html/svg/attributes content_style_type","url":"sprocket/html/svg/attributes.html#content_style_type"},{"doc":"sprocket/html/svg/attributes","title":"crossorigin","content":"pub fn crossorigin(value: String) -&gt; Attribute\n The [SVG `crossorigin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/crossorigin)\nSynonyms:\nsprocket/html/svg/attributes.crossorigin\nsprocket/html/svg/attributes crossorigin","url":"sprocket/html/svg/attributes.html#crossorigin"},{"doc":"sprocket/html/svg/attributes","title":"cursor","content":"pub fn cursor(value: String) -&gt; Attribute\n The [SVG `cursor` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cursor)\nSynonyms:\nsprocket/html/svg/attributes.cursor\nsprocket/html/svg/attributes cursor","url":"sprocket/html/svg/attributes.html#cursor"},{"doc":"sprocket/html/svg/attributes","title":"cx","content":"pub fn cx(value: String) -&gt; Attribute\n The [SVG `cx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cx)\nSynonyms:\nsprocket/html/svg/attributes.cx\nsprocket/html/svg/attributes cx","url":"sprocket/html/svg/attributes.html#cx"},{"doc":"sprocket/html/svg/attributes","title":"cy","content":"pub fn cy(value: String) -&gt; Attribute\n The [SVG `cy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cy)\nSynonyms:\nsprocket/html/svg/attributes.cy\nsprocket/html/svg/attributes cy","url":"sprocket/html/svg/attributes.html#cy"},{"doc":"sprocket/html/svg/attributes","title":"d","content":"pub fn d(value: String) -&gt; Attribute\n The [SVG `d` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/d)\nSynonyms:\nsprocket/html/svg/attributes.d\nsprocket/html/svg/attributes d","url":"sprocket/html/svg/attributes.html#d"},{"doc":"sprocket/html/svg/attributes","title":"decelerate","content":"pub fn decelerate(value: String) -&gt; Attribute\n The [SVG `decelerate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/decelerate)\nSynonyms:\nsprocket/html/svg/attributes.decelerate\nsprocket/html/svg/attributes decelerate","url":"sprocket/html/svg/attributes.html#decelerate"},{"doc":"sprocket/html/svg/attributes","title":"descent","content":"pub fn descent(value: String) -&gt; Attribute\n The [SVG `descent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/descent)\nSynonyms:\nsprocket/html/svg/attributes.descent\nsprocket/html/svg/attributes descent","url":"sprocket/html/svg/attributes.html#descent"},{"doc":"sprocket/html/svg/attributes","title":"diffuse_constant","content":"pub fn diffuse_constant(value: String) -&gt; Attribute\n The [SVG `diffuseConstant` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/diffuseConstant)\nSynonyms:\nsprocket/html/svg/attributes.diffuse_constant\nsprocket/html/svg/attributes diffuse_constant","url":"sprocket/html/svg/attributes.html#diffuse_constant"},{"doc":"sprocket/html/svg/attributes","title":"direction","content":"pub fn direction(value: String) -&gt; Attribute\n The [SVG `direction` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/direction)\nSynonyms:\nsprocket/html/svg/attributes.direction\nsprocket/html/svg/attributes direction","url":"sprocket/html/svg/attributes.html#direction"},{"doc":"sprocket/html/svg/attributes","title":"display","content":"pub fn display(value: String) -&gt; Attribute\n The [SVG `display` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/display)\nSynonyms:\nsprocket/html/svg/attributes.display\nsprocket/html/svg/attributes display","url":"sprocket/html/svg/attributes.html#display"},{"doc":"sprocket/html/svg/attributes","title":"divisor","content":"pub fn divisor(value: String) -&gt; Attribute\n The [SVG `divisor` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/divisor)\nSynonyms:\nsprocket/html/svg/attributes.divisor\nsprocket/html/svg/attributes divisor","url":"sprocket/html/svg/attributes.html#divisor"},{"doc":"sprocket/html/svg/attributes","title":"dominant_baseline","content":"pub fn dominant_baseline(value: String) -&gt; Attribute\n The [SVG `dominant-baseline` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dominant-baseline)\nSynonyms:\nsprocket/html/svg/attributes.dominant_baseline\nsprocket/html/svg/attributes dominant_baseline","url":"sprocket/html/svg/attributes.html#dominant_baseline"},{"doc":"sprocket/html/svg/attributes","title":"dur","content":"pub fn dur(value: String) -&gt; Attribute\n The [SVG `dur` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dur)\nSynonyms:\nsprocket/html/svg/attributes.dur\nsprocket/html/svg/attributes dur","url":"sprocket/html/svg/attributes.html#dur"},{"doc":"sprocket/html/svg/attributes","title":"dx","content":"pub fn dx(value: String) -&gt; Attribute\n The [SVG `dx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dx)\nSynonyms:\nsprocket/html/svg/attributes.dx\nsprocket/html/svg/attributes dx","url":"sprocket/html/svg/attributes.html#dx"},{"doc":"sprocket/html/svg/attributes","title":"dy","content":"pub fn dy(value: String) -&gt; Attribute\n The [SVG `dy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dy)\nSynonyms:\nsprocket/html/svg/attributes.dy\nsprocket/html/svg/attributes dy","url":"sprocket/html/svg/attributes.html#dy"},{"doc":"sprocket/html/svg/attributes","title":"edge_mode","content":"pub fn edge_mode(value: String) -&gt; Attribute\n The [SVG `edgeMode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/edgeMode)\nSynonyms:\nsprocket/html/svg/attributes.edge_mode\nsprocket/html/svg/attributes edge_mode","url":"sprocket/html/svg/attributes.html#edge_mode"},{"doc":"sprocket/html/svg/attributes","title":"elevation","content":"pub fn elevation(value: String) -&gt; Attribute\n The [SVG `elevation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/elevation)\nSynonyms:\nsprocket/html/svg/attributes.elevation\nsprocket/html/svg/attributes elevation","url":"sprocket/html/svg/attributes.html#elevation"},{"doc":"sprocket/html/svg/attributes","title":"enable_background","content":"pub fn enable_background(value: String) -&gt; Attribute\n The [SVG `enable-background` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/enable-background)\nSynonyms:\nsprocket/html/svg/attributes.enable_background\nsprocket/html/svg/attributes enable_background","url":"sprocket/html/svg/attributes.html#enable_background"},{"doc":"sprocket/html/svg/attributes","title":"end","content":"pub fn end(value: String) -&gt; Attribute\n The [SVG `end` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/end)\nSynonyms:\nsprocket/html/svg/attributes.end\nsprocket/html/svg/attributes end","url":"sprocket/html/svg/attributes.html#end"},{"doc":"sprocket/html/svg/attributes","title":"exponent","content":"pub fn exponent(value: String) -&gt; Attribute\n The [SVG `exponent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/exponent)\nSynonyms:\nsprocket/html/svg/attributes.exponent\nsprocket/html/svg/attributes exponent","url":"sprocket/html/svg/attributes.html#exponent"},{"doc":"sprocket/html/svg/attributes","title":"fill","content":"pub fn fill(value: String) -&gt; Attribute\n The [SVG `fill` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fill)\nSynonyms:\nsprocket/html/svg/attributes.fill\nsprocket/html/svg/attributes fill","url":"sprocket/html/svg/attributes.html#fill"},{"doc":"sprocket/html/svg/attributes","title":"fill_opacity","content":"pub fn fill_opacity(value: String) -&gt; Attribute\n The [SVG `fill-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fill-opacity)\nSynonyms:\nsprocket/html/svg/attributes.fill_opacity\nsprocket/html/svg/attributes fill_opacity","url":"sprocket/html/svg/attributes.html#fill_opacity"},{"doc":"sprocket/html/svg/attributes","title":"fill_rule","content":"pub fn fill_rule(value: String) -&gt; Attribute\n The [SVG `fill-rule` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fill-rule)\nSynonyms:\nsprocket/html/svg/attributes.fill_rule\nsprocket/html/svg/attributes fill_rule","url":"sprocket/html/svg/attributes.html#fill_rule"},{"doc":"sprocket/html/svg/attributes","title":"filter","content":"pub fn filter(value: String) -&gt; Attribute\n The [SVG `filter` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/filter)\nSynonyms:\nsprocket/html/svg/attributes.filter\nsprocket/html/svg/attributes filter","url":"sprocket/html/svg/attributes.html#filter"},{"doc":"sprocket/html/svg/attributes","title":"filter_res","content":"pub fn filter_res(value: String) -&gt; Attribute\n The [SVG `filterRes` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/filterRes)\nSynonyms:\nsprocket/html/svg/attributes.filter_res\nsprocket/html/svg/attributes filter_res","url":"sprocket/html/svg/attributes.html#filter_res"},{"doc":"sprocket/html/svg/attributes","title":"filter_units","content":"pub fn filter_units(value: String) -&gt; Attribute\n The [SVG `filterUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/filterUnits)\nSynonyms:\nsprocket/html/svg/attributes.filter_units\nsprocket/html/svg/attributes filter_units","url":"sprocket/html/svg/attributes.html#filter_units"},{"doc":"sprocket/html/svg/attributes","title":"flood_color","content":"pub fn flood_color(value: String) -&gt; Attribute\n The [SVG `flood-color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/flood-color)\nSynonyms:\nsprocket/html/svg/attributes.flood_color\nsprocket/html/svg/attributes flood_color","url":"sprocket/html/svg/attributes.html#flood_color"},{"doc":"sprocket/html/svg/attributes","title":"flood_opacity","content":"pub fn flood_opacity(value: String) -&gt; Attribute\n The [SVG `flood-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/flood-opacity)\nSynonyms:\nsprocket/html/svg/attributes.flood_opacity\nsprocket/html/svg/attributes flood_opacity","url":"sprocket/html/svg/attributes.html#flood_opacity"},{"doc":"sprocket/html/svg/attributes","title":"font_family","content":"pub fn font_family(value: String) -&gt; Attribute\n The [SVG `font-family` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-family)\nSynonyms:\nsprocket/html/svg/attributes.font_family\nsprocket/html/svg/attributes font_family","url":"sprocket/html/svg/attributes.html#font_family"},{"doc":"sprocket/html/svg/attributes","title":"font_size","content":"pub fn font_size(value: String) -&gt; Attribute\n The [SVG `font-size` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-size)\nSynonyms:\nsprocket/html/svg/attributes.font_size\nsprocket/html/svg/attributes font_size","url":"sprocket/html/svg/attributes.html#font_size"},{"doc":"sprocket/html/svg/attributes","title":"font_size_adjust","content":"pub fn font_size_adjust(value: String) -&gt; Attribute\n The [SVG `font-size-adjust` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-size-adjust)\nSynonyms:\nsprocket/html/svg/attributes.font_size_adjust\nsprocket/html/svg/attributes font_size_adjust","url":"sprocket/html/svg/attributes.html#font_size_adjust"},{"doc":"sprocket/html/svg/attributes","title":"font_stretch","content":"pub fn font_stretch(value: String) -&gt; Attribute\n The [SVG `font-stretch` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-stretch)\nSynonyms:\nsprocket/html/svg/attributes.font_stretch\nsprocket/html/svg/attributes font_stretch","url":"sprocket/html/svg/attributes.html#font_stretch"},{"doc":"sprocket/html/svg/attributes","title":"font_style","content":"pub fn font_style(value: String) -&gt; Attribute\n The [SVG `font-style` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-style)\nSynonyms:\nsprocket/html/svg/attributes.font_style\nsprocket/html/svg/attributes font_style","url":"sprocket/html/svg/attributes.html#font_style"},{"doc":"sprocket/html/svg/attributes","title":"font_variant","content":"pub fn font_variant(value: String) -&gt; Attribute\n The [SVG `font-variant` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-variant)\nSynonyms:\nsprocket/html/svg/attributes.font_variant\nsprocket/html/svg/attributes font_variant","url":"sprocket/html/svg/attributes.html#font_variant"},{"doc":"sprocket/html/svg/attributes","title":"font_weight","content":"pub fn font_weight(value: String) -&gt; Attribute\n The [SVG `font-weight` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-weight)\nSynonyms:\nsprocket/html/svg/attributes.font_weight\nsprocket/html/svg/attributes font_weight","url":"sprocket/html/svg/attributes.html#font_weight"},{"doc":"sprocket/html/svg/attributes","title":"format","content":"pub fn format(value: String) -&gt; Attribute\n The [SVG `format` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/format)\nSynonyms:\nsprocket/html/svg/attributes.format\nsprocket/html/svg/attributes format","url":"sprocket/html/svg/attributes.html#format"},{"doc":"sprocket/html/svg/attributes","title":"fr","content":"pub fn fr(value: String) -&gt; Attribute\n The [SVG `fr` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fr)\nSynonyms:\nsprocket/html/svg/attributes.fr\nsprocket/html/svg/attributes fr","url":"sprocket/html/svg/attributes.html#fr"},{"doc":"sprocket/html/svg/attributes","title":"from","content":"pub fn from(value: String) -&gt; Attribute\n The [SVG `from` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/from)\nSynonyms:\nsprocket/html/svg/attributes.from\nsprocket/html/svg/attributes from","url":"sprocket/html/svg/attributes.html#from"},{"doc":"sprocket/html/svg/attributes","title":"fx","content":"pub fn fx(value: String) -&gt; Attribute\n The [SVG `fx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fx)\nSynonyms:\nsprocket/html/svg/attributes.fx\nsprocket/html/svg/attributes fx","url":"sprocket/html/svg/attributes.html#fx"},{"doc":"sprocket/html/svg/attributes","title":"fy","content":"pub fn fy(value: String) -&gt; Attribute\n The [SVG `fy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fy)\nSynonyms:\nsprocket/html/svg/attributes.fy\nsprocket/html/svg/attributes fy","url":"sprocket/html/svg/attributes.html#fy"},{"doc":"sprocket/html/svg/attributes","title":"g1","content":"pub fn g1(value: String) -&gt; Attribute\n The [SVG `g1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/g1)\nSynonyms:\nsprocket/html/svg/attributes.g1\nsprocket/html/svg/attributes g1","url":"sprocket/html/svg/attributes.html#g1"},{"doc":"sprocket/html/svg/attributes","title":"g2","content":"pub fn g2(value: String) -&gt; Attribute\n The [SVG `g2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/g2)\nSynonyms:\nsprocket/html/svg/attributes.g2\nsprocket/html/svg/attributes g2","url":"sprocket/html/svg/attributes.html#g2"},{"doc":"sprocket/html/svg/attributes","title":"glyph_name","content":"pub fn glyph_name(value: String) -&gt; Attribute\n The [SVG `glyph-name` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyph-name)\nSynonyms:\nsprocket/html/svg/attributes.glyph_name\nsprocket/html/svg/attributes glyph_name","url":"sprocket/html/svg/attributes.html#glyph_name"},{"doc":"sprocket/html/svg/attributes","title":"glyph_orientation_horizontal","content":"pub fn glyph_orientation_horizontal(value: String) -&gt; Attribute\n The [SVG `glyph-orientation-horizontal` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyph-orientation-horizontal)\nSynonyms:\nsprocket/html/svg/attributes.glyph_orientation_horizontal\nsprocket/html/svg/attributes glyph_orientation_horizontal","url":"sprocket/html/svg/attributes.html#glyph_orientation_horizontal"},{"doc":"sprocket/html/svg/attributes","title":"glyph_orientation_vertical","content":"pub fn glyph_orientation_vertical(value: String) -&gt; Attribute\n The [SVG `glyph-orientation-vertical` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyph-orientation-vertical)\nSynonyms:\nsprocket/html/svg/attributes.glyph_orientation_vertical\nsprocket/html/svg/attributes glyph_orientation_vertical","url":"sprocket/html/svg/attributes.html#glyph_orientation_vertical"},{"doc":"sprocket/html/svg/attributes","title":"glyph_ref","content":"pub fn glyph_ref(value: String) -&gt; Attribute\n The [SVG `glyphRef` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyphRef)\nSynonyms:\nsprocket/html/svg/attributes.glyph_ref\nsprocket/html/svg/attributes glyph_ref","url":"sprocket/html/svg/attributes.html#glyph_ref"},{"doc":"sprocket/html/svg/attributes","title":"gradient_transform","content":"pub fn gradient_transform(value: String) -&gt; Attribute\n The [SVG `gradientTransform` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/gradientTransform)\nSynonyms:\nsprocket/html/svg/attributes.gradient_transform\nsprocket/html/svg/attributes gradient_transform","url":"sprocket/html/svg/attributes.html#gradient_transform"},{"doc":"sprocket/html/svg/attributes","title":"gradient_units","content":"pub fn gradient_units(value: String) -&gt; Attribute\n The [SVG `gradientUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/gradientUnits)\nSynonyms:\nsprocket/html/svg/attributes.gradient_units\nsprocket/html/svg/attributes gradient_units","url":"sprocket/html/svg/attributes.html#gradient_units"},{"doc":"sprocket/html/svg/attributes","title":"hanging","content":"pub fn hanging(value: String) -&gt; Attribute\n The [SVG `hanging` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/hanging)\nSynonyms:\nsprocket/html/svg/attributes.hanging\nsprocket/html/svg/attributes hanging","url":"sprocket/html/svg/attributes.html#hanging"},{"doc":"sprocket/html/svg/attributes","title":"height","content":"pub fn height(value: String) -&gt; Attribute\n The [SVG `height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/height)\nSynonyms:\nsprocket/html/svg/attributes.height\nsprocket/html/svg/attributes height","url":"sprocket/html/svg/attributes.html#height"},{"doc":"sprocket/html/svg/attributes","title":"horiz_adv_x","content":"pub fn horiz_adv_x(value: String) -&gt; Attribute\n The [SVG `horiz-adv-x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/horiz-adv-x)\nSynonyms:\nsprocket/html/svg/attributes.horiz_adv_x\nsprocket/html/svg/attributes horiz_adv_x","url":"sprocket/html/svg/attributes.html#horiz_adv_x"},{"doc":"sprocket/html/svg/attributes","title":"horiz_origin_x","content":"pub fn horiz_origin_x(value: String) -&gt; Attribute\n The [SVG `horiz-origin-x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/horiz-origin-x)\nSynonyms:\nsprocket/html/svg/attributes.horiz_origin_x\nsprocket/html/svg/attributes horiz_origin_x","url":"sprocket/html/svg/attributes.html#horiz_origin_x"},{"doc":"sprocket/html/svg/attributes","title":"href","content":"pub fn href(value: String) -&gt; Attribute\n The [SVG `href` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/href)\nSynonyms:\nsprocket/html/svg/attributes.href\nsprocket/html/svg/attributes href","url":"sprocket/html/svg/attributes.html#href"},{"doc":"sprocket/html/svg/attributes","title":"hreflang","content":"pub fn hreflang(value: String) -&gt; Attribute\n The [SVG `hreflang` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/hreflang)\nSynonyms:\nsprocket/html/svg/attributes.hreflang\nsprocket/html/svg/attributes hreflang","url":"sprocket/html/svg/attributes.html#hreflang"},{"doc":"sprocket/html/svg/attributes","title":"id","content":"pub fn id(value: String) -&gt; Attribute\n The [SVG `id` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/id)\nSynonyms:\nsprocket/html/svg/attributes.id\nsprocket/html/svg/attributes id","url":"sprocket/html/svg/attributes.html#id"},{"doc":"sprocket/html/svg/attributes","title":"ideographic","content":"pub fn ideographic(value: String) -&gt; Attribute\n The [SVG `ideographic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ideographic)\nSynonyms:\nsprocket/html/svg/attributes.ideographic\nsprocket/html/svg/attributes ideographic","url":"sprocket/html/svg/attributes.html#ideographic"},{"doc":"sprocket/html/svg/attributes","title":"image_rendering","content":"pub fn image_rendering(value: String) -&gt; Attribute\n The [SVG `image-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/image-rendering)\nSynonyms:\nsprocket/html/svg/attributes.image_rendering\nsprocket/html/svg/attributes image_rendering","url":"sprocket/html/svg/attributes.html#image_rendering"},{"doc":"sprocket/html/svg/attributes","title":"in","content":"pub fn in(value: String) -&gt; Attribute\n The [SVG `in` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/in)\nSynonyms:\nsprocket/html/svg/attributes.in\nsprocket/html/svg/attributes in","url":"sprocket/html/svg/attributes.html#in"},{"doc":"sprocket/html/svg/attributes","title":"in2","content":"pub fn in2(value: String) -&gt; Attribute\n The [SVG `in2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/in2)\nSynonyms:\nsprocket/html/svg/attributes.in2\nsprocket/html/svg/attributes in2","url":"sprocket/html/svg/attributes.html#in2"},{"doc":"sprocket/html/svg/attributes","title":"intercept","content":"pub fn intercept(value: String) -&gt; Attribute\n The [SVG `intercept` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/intercept)\nSynonyms:\nsprocket/html/svg/attributes.intercept\nsprocket/html/svg/attributes intercept","url":"sprocket/html/svg/attributes.html#intercept"},{"doc":"sprocket/html/svg/attributes","title":"k","content":"pub fn k(value: String) -&gt; Attribute\n The [SVG `k` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k)\nSynonyms:\nsprocket/html/svg/attributes.k\nsprocket/html/svg/attributes k","url":"sprocket/html/svg/attributes.html#k"},{"doc":"sprocket/html/svg/attributes","title":"k1","content":"pub fn k1(value: String) -&gt; Attribute\n The [SVG `k1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k1)\nSynonyms:\nsprocket/html/svg/attributes.k1\nsprocket/html/svg/attributes k1","url":"sprocket/html/svg/attributes.html#k1"},{"doc":"sprocket/html/svg/attributes","title":"k2","content":"pub fn k2(value: String) -&gt; Attribute\n The [SVG `k2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k2)\nSynonyms:\nsprocket/html/svg/attributes.k2\nsprocket/html/svg/attributes k2","url":"sprocket/html/svg/attributes.html#k2"},{"doc":"sprocket/html/svg/attributes","title":"k3","content":"pub fn k3(value: String) -&gt; Attribute\n The [SVG `k3` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k3)\nSynonyms:\nsprocket/html/svg/attributes.k3\nsprocket/html/svg/attributes k3","url":"sprocket/html/svg/attributes.html#k3"},{"doc":"sprocket/html/svg/attributes","title":"k4","content":"pub fn k4(value: String) -&gt; Attribute\n The [SVG `k4` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k4)\nSynonyms:\nsprocket/html/svg/attributes.k4\nsprocket/html/svg/attributes k4","url":"sprocket/html/svg/attributes.html#k4"},{"doc":"sprocket/html/svg/attributes","title":"kernel_matrix","content":"pub fn kernel_matrix(value: String) -&gt; Attribute\n The [SVG `kernelMatrix` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/kernelMatrix)\nSynonyms:\nsprocket/html/svg/attributes.kernel_matrix\nsprocket/html/svg/attributes kernel_matrix","url":"sprocket/html/svg/attributes.html#kernel_matrix"},{"doc":"sprocket/html/svg/attributes","title":"kernel_unit_length","content":"pub fn kernel_unit_length(value: String) -&gt; Attribute\n The [SVG `kernelUnitLength` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/kernelUnitLength)\nSynonyms:\nsprocket/html/svg/attributes.kernel_unit_length\nsprocket/html/svg/attributes kernel_unit_length","url":"sprocket/html/svg/attributes.html#kernel_unit_length"},{"doc":"sprocket/html/svg/attributes","title":"kerning","content":"pub fn kerning(value: String) -&gt; Attribute\n The [SVG `kerning` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/kerning)\nSynonyms:\nsprocket/html/svg/attributes.kerning\nsprocket/html/svg/attributes kerning","url":"sprocket/html/svg/attributes.html#kerning"},{"doc":"sprocket/html/svg/attributes","title":"key_points","content":"pub fn key_points(value: String) -&gt; Attribute\n The [SVG `keyPoints` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/keyPoints)\nSynonyms:\nsprocket/html/svg/attributes.key_points\nsprocket/html/svg/attributes key_points","url":"sprocket/html/svg/attributes.html#key_points"},{"doc":"sprocket/html/svg/attributes","title":"key_splines","content":"pub fn key_splines(value: String) -&gt; Attribute\n The [SVG `keySplines` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/keySplines)\nSynonyms:\nsprocket/html/svg/attributes.key_splines\nsprocket/html/svg/attributes key_splines","url":"sprocket/html/svg/attributes.html#key_splines"},{"doc":"sprocket/html/svg/attributes","title":"key_times","content":"pub fn key_times(value: String) -&gt; Attribute\n The [SVG `keyTimes` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/keyTimes)\nSynonyms:\nsprocket/html/svg/attributes.key_times\nsprocket/html/svg/attributes key_times","url":"sprocket/html/svg/attributes.html#key_times"},{"doc":"sprocket/html/svg/attributes","title":"lang","content":"pub fn lang(value: String) -&gt; Attribute\n The [SVG `lang` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/lang)\nSynonyms:\nsprocket/html/svg/attributes.lang\nsprocket/html/svg/attributes lang","url":"sprocket/html/svg/attributes.html#lang"},{"doc":"sprocket/html/svg/attributes","title":"length_adjust","content":"pub fn length_adjust(value: String) -&gt; Attribute\n The [SVG `lengthAdjust` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/lengthAdjust)\nSynonyms:\nsprocket/html/svg/attributes.length_adjust\nsprocket/html/svg/attributes length_adjust","url":"sprocket/html/svg/attributes.html#length_adjust"},{"doc":"sprocket/html/svg/attributes","title":"letter_spacing","content":"pub fn letter_spacing(value: String) -&gt; Attribute\n The [SVG `letter-spacing` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/letter-spacing)\nSynonyms:\nsprocket/html/svg/attributes.letter_spacing\nsprocket/html/svg/attributes letter_spacing","url":"sprocket/html/svg/attributes.html#letter_spacing"},{"doc":"sprocket/html/svg/attributes","title":"lighting_color","content":"pub fn lighting_color(value: String) -&gt; Attribute\n The [SVG `lighting-color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/lighting-color)\nSynonyms:\nsprocket/html/svg/attributes.lighting_color\nsprocket/html/svg/attributes lighting_color","url":"sprocket/html/svg/attributes.html#lighting_color"},{"doc":"sprocket/html/svg/attributes","title":"limiting_cone_angle","content":"pub fn limiting_cone_angle(value: String) -&gt; Attribute\n The [SVG `limitingConeAngle` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/limitingConeAngle)\nSynonyms:\nsprocket/html/svg/attributes.limiting_cone_angle\nsprocket/html/svg/attributes limiting_cone_angle","url":"sprocket/html/svg/attributes.html#limiting_cone_angle"},{"doc":"sprocket/html/svg/attributes","title":"local","content":"pub fn local(value: String) -&gt; Attribute\n The [SVG `local` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/local)\nSynonyms:\nsprocket/html/svg/attributes.local\nsprocket/html/svg/attributes local","url":"sprocket/html/svg/attributes.html#local"},{"doc":"sprocket/html/svg/attributes","title":"marker_end","content":"pub fn marker_end(value: String) -&gt; Attribute\n The [SVG `marker-end` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/marker-end)\nSynonyms:\nsprocket/html/svg/attributes.marker_end\nsprocket/html/svg/attributes marker_end","url":"sprocket/html/svg/attributes.html#marker_end"},{"doc":"sprocket/html/svg/attributes","title":"marker_height","content":"pub fn marker_height(value: String) -&gt; Attribute\n The [SVG `markerHeight` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/markerHeight)\nSynonyms:\nsprocket/html/svg/attributes.marker_height\nsprocket/html/svg/attributes marker_height","url":"sprocket/html/svg/attributes.html#marker_height"},{"doc":"sprocket/html/svg/attributes","title":"marker_mid","content":"pub fn marker_mid(value: String) -&gt; Attribute\n The [SVG `marker-mid` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/marker-mid)\nSynonyms:\nsprocket/html/svg/attributes.marker_mid\nsprocket/html/svg/attributes marker_mid","url":"sprocket/html/svg/attributes.html#marker_mid"},{"doc":"sprocket/html/svg/attributes","title":"marker_start","content":"pub fn marker_start(value: String) -&gt; Attribute\n The [SVG `marker-start` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/marker-start)\nSynonyms:\nsprocket/html/svg/attributes.marker_start\nsprocket/html/svg/attributes marker_start","url":"sprocket/html/svg/attributes.html#marker_start"},{"doc":"sprocket/html/svg/attributes","title":"marker_units","content":"pub fn marker_units(value: String) -&gt; Attribute\n The [SVG `markerUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/markerUnits)\nSynonyms:\nsprocket/html/svg/attributes.marker_units\nsprocket/html/svg/attributes marker_units","url":"sprocket/html/svg/attributes.html#marker_units"},{"doc":"sprocket/html/svg/attributes","title":"marker_width","content":"pub fn marker_width(value: String) -&gt; Attribute\n The [SVG `markerWidth` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/markerWidth)\nSynonyms:\nsprocket/html/svg/attributes.marker_width\nsprocket/html/svg/attributes marker_width","url":"sprocket/html/svg/attributes.html#marker_width"},{"doc":"sprocket/html/svg/attributes","title":"mask","content":"pub fn mask(value: String) -&gt; Attribute\n The [SVG `mask` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/mask)\nSynonyms:\nsprocket/html/svg/attributes.mask\nsprocket/html/svg/attributes mask","url":"sprocket/html/svg/attributes.html#mask"},{"doc":"sprocket/html/svg/attributes","title":"mask_content_units","content":"pub fn mask_content_units(value: String) -&gt; Attribute\n The [SVG `maskContentUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/maskContentUnits)\nSynonyms:\nsprocket/html/svg/attributes.mask_content_units\nsprocket/html/svg/attributes mask_content_units","url":"sprocket/html/svg/attributes.html#mask_content_units"},{"doc":"sprocket/html/svg/attributes","title":"mask_units","content":"pub fn mask_units(value: String) -&gt; Attribute\n The [SVG `maskUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/maskUnits)\nSynonyms:\nsprocket/html/svg/attributes.mask_units\nsprocket/html/svg/attributes mask_units","url":"sprocket/html/svg/attributes.html#mask_units"},{"doc":"sprocket/html/svg/attributes","title":"mathematical","content":"pub fn mathematical(value: String) -&gt; Attribute\n The [SVG `mathematical` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/mathematical)\nSynonyms:\nsprocket/html/svg/attributes.mathematical\nsprocket/html/svg/attributes mathematical","url":"sprocket/html/svg/attributes.html#mathematical"},{"doc":"sprocket/html/svg/attributes","title":"max","content":"pub fn max(value: String) -&gt; Attribute\n The [SVG `max` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/max)\nSynonyms:\nsprocket/html/svg/attributes.max\nsprocket/html/svg/attributes max","url":"sprocket/html/svg/attributes.html#max"},{"doc":"sprocket/html/svg/attributes","title":"media","content":"pub fn media(value: String) -&gt; Attribute\n The [SVG `media` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/media)\nSynonyms:\nsprocket/html/svg/attributes.media\nsprocket/html/svg/attributes media","url":"sprocket/html/svg/attributes.html#media"},{"doc":"sprocket/html/svg/attributes","title":"method","content":"pub fn method(value: String) -&gt; Attribute\n The [SVG `method` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/method)\nSynonyms:\nsprocket/html/svg/attributes.method\nsprocket/html/svg/attributes method","url":"sprocket/html/svg/attributes.html#method"},{"doc":"sprocket/html/svg/attributes","title":"min","content":"pub fn min(value: String) -&gt; Attribute\n The [SVG `min` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/min)\nSynonyms:\nsprocket/html/svg/attributes.min\nsprocket/html/svg/attributes min","url":"sprocket/html/svg/attributes.html#min"},{"doc":"sprocket/html/svg/attributes","title":"mode","content":"pub fn mode(value: String) -&gt; Attribute\n The [SVG `mode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/mode)\nSynonyms:\nsprocket/html/svg/attributes.mode\nsprocket/html/svg/attributes mode","url":"sprocket/html/svg/attributes.html#mode"},{"doc":"sprocket/html/svg/attributes","title":"name","content":"pub fn name(value: String) -&gt; Attribute\n The [SVG `name` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/name)\nSynonyms:\nsprocket/html/svg/attributes.name\nsprocket/html/svg/attributes name","url":"sprocket/html/svg/attributes.html#name"},{"doc":"sprocket/html/svg/attributes","title":"num_octaves","content":"pub fn num_octaves(value: String) -&gt; Attribute\n The [SVG `numOctaves` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/numOctaves)\nSynonyms:\nsprocket/html/svg/attributes.num_octaves\nsprocket/html/svg/attributes num_octaves","url":"sprocket/html/svg/attributes.html#num_octaves"},{"doc":"sprocket/html/svg/attributes","title":"offset","content":"pub fn offset(value: String) -&gt; Attribute\n The [SVG `offset` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/offset)\nSynonyms:\nsprocket/html/svg/attributes.offset\nsprocket/html/svg/attributes offset","url":"sprocket/html/svg/attributes.html#offset"},{"doc":"sprocket/html/svg/attributes","title":"opacity","content":"pub fn opacity(value: String) -&gt; Attribute\n The [SVG `opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/opacity)\nSynonyms:\nsprocket/html/svg/attributes.opacity\nsprocket/html/svg/attributes opacity","url":"sprocket/html/svg/attributes.html#opacity"},{"doc":"sprocket/html/svg/attributes","title":"operator","content":"pub fn operator(value: String) -&gt; Attribute\n The [SVG `operator` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/operator)\nSynonyms:\nsprocket/html/svg/attributes.operator\nsprocket/html/svg/attributes operator","url":"sprocket/html/svg/attributes.html#operator"},{"doc":"sprocket/html/svg/attributes","title":"order","content":"pub fn order(value: String) -&gt; Attribute\n The [SVG `order` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/order)\nSynonyms:\nsprocket/html/svg/attributes.order\nsprocket/html/svg/attributes order","url":"sprocket/html/svg/attributes.html#order"},{"doc":"sprocket/html/svg/attributes","title":"orient","content":"pub fn orient(value: String) -&gt; Attribute\n The [SVG `orient` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/orient)\nSynonyms:\nsprocket/html/svg/attributes.orient\nsprocket/html/svg/attributes orient","url":"sprocket/html/svg/attributes.html#orient"},{"doc":"sprocket/html/svg/attributes","title":"orientation","content":"pub fn orientation(value: String) -&gt; Attribute\n The [SVG `orientation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/orientation)\nSynonyms:\nsprocket/html/svg/attributes.orientation\nsprocket/html/svg/attributes orientation","url":"sprocket/html/svg/attributes.html#orientation"},{"doc":"sprocket/html/svg/attributes","title":"origin","content":"pub fn origin(value: String) -&gt; Attribute\n The [SVG `origin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/origin)\nSynonyms:\nsprocket/html/svg/attributes.origin\nsprocket/html/svg/attributes origin","url":"sprocket/html/svg/attributes.html#origin"},{"doc":"sprocket/html/svg/attributes","title":"overflow","content":"pub fn overflow(value: String) -&gt; Attribute\n The [SVG `overflow` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/overflow)\nSynonyms:\nsprocket/html/svg/attributes.overflow\nsprocket/html/svg/attributes overflow","url":"sprocket/html/svg/attributes.html#overflow"},{"doc":"sprocket/html/svg/attributes","title":"overline_position","content":"pub fn overline_position(value: String) -&gt; Attribute\n The [SVG `overline-position` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/overline-position)\nSynonyms:\nsprocket/html/svg/attributes.overline_position\nsprocket/html/svg/attributes overline_position","url":"sprocket/html/svg/attributes.html#overline_position"},{"doc":"sprocket/html/svg/attributes","title":"overline_thickness","content":"pub fn overline_thickness(value: String) -&gt; Attribute\n The [SVG `overline-thickness` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/overline-thickness)\nSynonyms:\nsprocket/html/svg/attributes.overline_thickness\nsprocket/html/svg/attributes overline_thickness","url":"sprocket/html/svg/attributes.html#overline_thickness"},{"doc":"sprocket/html/svg/attributes","title":"paint_order","content":"pub fn paint_order(value: String) -&gt; Attribute\n The [SVG `paint-order` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/paint-order)\nSynonyms:\nsprocket/html/svg/attributes.paint_order\nsprocket/html/svg/attributes paint_order","url":"sprocket/html/svg/attributes.html#paint_order"},{"doc":"sprocket/html/svg/attributes","title":"panose_1","content":"pub fn panose_1(value: String) -&gt; Attribute\n The [SVG `panose-1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/panose-1)\nSynonyms:\nsprocket/html/svg/attributes.panose_1\nsprocket/html/svg/attributes panose_1","url":"sprocket/html/svg/attributes.html#panose_1"},{"doc":"sprocket/html/svg/attributes","title":"path","content":"pub fn path(value: String) -&gt; Attribute\n The [SVG `path` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/path)\nSynonyms:\nsprocket/html/svg/attributes.path\nsprocket/html/svg/attributes path","url":"sprocket/html/svg/attributes.html#path"},{"doc":"sprocket/html/svg/attributes","title":"path_length","content":"pub fn path_length(value: String) -&gt; Attribute\n The [SVG `pathLength` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pathLength)\nSynonyms:\nsprocket/html/svg/attributes.path_length\nsprocket/html/svg/attributes path_length","url":"sprocket/html/svg/attributes.html#path_length"},{"doc":"sprocket/html/svg/attributes","title":"pattern_content_units","content":"pub fn pattern_content_units(value: String) -&gt; Attribute\n The [SVG `patternContentUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/patternContentUnits)\nSynonyms:\nsprocket/html/svg/attributes.pattern_content_units\nsprocket/html/svg/attributes pattern_content_units","url":"sprocket/html/svg/attributes.html#pattern_content_units"},{"doc":"sprocket/html/svg/attributes","title":"pattern_transform","content":"pub fn pattern_transform(value: String) -&gt; Attribute\n The [SVG `patternTransform` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/patternTransform)\nSynonyms:\nsprocket/html/svg/attributes.pattern_transform\nsprocket/html/svg/attributes pattern_transform","url":"sprocket/html/svg/attributes.html#pattern_transform"},{"doc":"sprocket/html/svg/attributes","title":"pattern_units","content":"pub fn pattern_units(value: String) -&gt; Attribute\n The [SVG `patternUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/patternUnits)\nSynonyms:\nsprocket/html/svg/attributes.pattern_units\nsprocket/html/svg/attributes pattern_units","url":"sprocket/html/svg/attributes.html#pattern_units"},{"doc":"sprocket/html/svg/attributes","title":"ping","content":"pub fn ping(value: String) -&gt; Attribute\n The [SVG `ping` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ping)\nSynonyms:\nsprocket/html/svg/attributes.ping\nsprocket/html/svg/attributes ping","url":"sprocket/html/svg/attributes.html#ping"},{"doc":"sprocket/html/svg/attributes","title":"pointer_events","content":"pub fn pointer_events(value: String) -&gt; Attribute\n The [SVG `pointer-events` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointer-events)\nSynonyms:\nsprocket/html/svg/attributes.pointer_events\nsprocket/html/svg/attributes pointer_events","url":"sprocket/html/svg/attributes.html#pointer_events"},{"doc":"sprocket/html/svg/attributes","title":"points","content":"pub fn points(value: String) -&gt; Attribute\n The [SVG `points` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/points)\nSynonyms:\nsprocket/html/svg/attributes.points\nsprocket/html/svg/attributes points","url":"sprocket/html/svg/attributes.html#points"},{"doc":"sprocket/html/svg/attributes","title":"points_at_x","content":"pub fn points_at_x(value: String) -&gt; Attribute\n The [SVG `pointsAtX` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointsAtX)\nSynonyms:\nsprocket/html/svg/attributes.points_at_x\nsprocket/html/svg/attributes points_at_x","url":"sprocket/html/svg/attributes.html#points_at_x"},{"doc":"sprocket/html/svg/attributes","title":"points_at_y","content":"pub fn points_at_y(value: String) -&gt; Attribute\n The [SVG `pointsAtY` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointsAtY)\nSynonyms:\nsprocket/html/svg/attributes.points_at_y\nsprocket/html/svg/attributes points_at_y","url":"sprocket/html/svg/attributes.html#points_at_y"},{"doc":"sprocket/html/svg/attributes","title":"points_at_z","content":"pub fn points_at_z(value: String) -&gt; Attribute\n The [SVG `pointsAtZ` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointsAtZ)\nSynonyms:\nsprocket/html/svg/attributes.points_at_z\nsprocket/html/svg/attributes points_at_z","url":"sprocket/html/svg/attributes.html#points_at_z"},{"doc":"sprocket/html/svg/attributes","title":"preserve_alpha","content":"pub fn preserve_alpha(value: String) -&gt; Attribute\n The [SVG `preserveAlpha` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/preserveAlpha)\nSynonyms:\nsprocket/html/svg/attributes.preserve_alpha\nsprocket/html/svg/attributes preserve_alpha","url":"sprocket/html/svg/attributes.html#preserve_alpha"},{"doc":"sprocket/html/svg/attributes","title":"preserve_aspect_ratio","content":"pub fn preserve_aspect_ratio(value: String) -&gt; Attribute\n The [SVG `preserveAspectRatio` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/preserveAspectRatio)\nSynonyms:\nsprocket/html/svg/attributes.preserve_aspect_ratio\nsprocket/html/svg/attributes preserve_aspect_ratio","url":"sprocket/html/svg/attributes.html#preserve_aspect_ratio"},{"doc":"sprocket/html/svg/attributes","title":"primitive_units","content":"pub fn primitive_units(value: String) -&gt; Attribute\n The [SVG `primitiveUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/primitiveUnits)\nSynonyms:\nsprocket/html/svg/attributes.primitive_units\nsprocket/html/svg/attributes primitive_units","url":"sprocket/html/svg/attributes.html#primitive_units"},{"doc":"sprocket/html/svg/attributes","title":"r","content":"pub fn r(value: String) -&gt; Attribute\n The [SVG `r` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/r)\nSynonyms:\nsprocket/html/svg/attributes.r\nsprocket/html/svg/attributes r","url":"sprocket/html/svg/attributes.html#r"},{"doc":"sprocket/html/svg/attributes","title":"radius","content":"pub fn radius(value: String) -&gt; Attribute\n The [SVG `radius` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/radius)\nSynonyms:\nsprocket/html/svg/attributes.radius\nsprocket/html/svg/attributes radius","url":"sprocket/html/svg/attributes.html#radius"},{"doc":"sprocket/html/svg/attributes","title":"ref_x","content":"pub fn ref_x(value: String) -&gt; Attribute\n The [SVG `refX` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/refX)\nSynonyms:\nsprocket/html/svg/attributes.ref_x\nsprocket/html/svg/attributes ref_x","url":"sprocket/html/svg/attributes.html#ref_x"},{"doc":"sprocket/html/svg/attributes","title":"ref_y","content":"pub fn ref_y(value: String) -&gt; Attribute\n The [SVG `refY` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/refY)\nSynonyms:\nsprocket/html/svg/attributes.ref_y\nsprocket/html/svg/attributes ref_y","url":"sprocket/html/svg/attributes.html#ref_y"},{"doc":"sprocket/html/svg/attributes","title":"referrer_policy","content":"pub fn referrer_policy(value: String) -&gt; Attribute\n The [SVG `referrerPolicy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/referrerPolicy)\nSynonyms:\nsprocket/html/svg/attributes.referrer_policy\nsprocket/html/svg/attributes referrer_policy","url":"sprocket/html/svg/attributes.html#referrer_policy"},{"doc":"sprocket/html/svg/attributes","title":"rel","content":"pub fn rel(value: String) -&gt; Attribute\n The [SVG `rel` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rel)\nSynonyms:\nsprocket/html/svg/attributes.rel\nsprocket/html/svg/attributes rel","url":"sprocket/html/svg/attributes.html#rel"},{"doc":"sprocket/html/svg/attributes","title":"rendering_intent","content":"pub fn rendering_intent(value: String) -&gt; Attribute\n The [SVG `rendering-intent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rendering-intent)\nSynonyms:\nsprocket/html/svg/attributes.rendering_intent\nsprocket/html/svg/attributes rendering_intent","url":"sprocket/html/svg/attributes.html#rendering_intent"},{"doc":"sprocket/html/svg/attributes","title":"repeat_count","content":"pub fn repeat_count(value: String) -&gt; Attribute\n The [SVG `repeatCount` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/repeatCount)\nSynonyms:\nsprocket/html/svg/attributes.repeat_count\nsprocket/html/svg/attributes repeat_count","url":"sprocket/html/svg/attributes.html#repeat_count"},{"doc":"sprocket/html/svg/attributes","title":"repeat_dur","content":"pub fn repeat_dur(value: String) -&gt; Attribute\n The [SVG `repeatDur` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/repeatDur)\nSynonyms:\nsprocket/html/svg/attributes.repeat_dur\nsprocket/html/svg/attributes repeat_dur","url":"sprocket/html/svg/attributes.html#repeat_dur"},{"doc":"sprocket/html/svg/attributes","title":"required_extensions","content":"pub fn required_extensions(value: String) -&gt; Attribute\n The [SVG `requiredExtensions` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/requiredExtensions)\nSynonyms:\nsprocket/html/svg/attributes.required_extensions\nsprocket/html/svg/attributes required_extensions","url":"sprocket/html/svg/attributes.html#required_extensions"},{"doc":"sprocket/html/svg/attributes","title":"required_features","content":"pub fn required_features(value: String) -&gt; Attribute\n The [SVG `requiredFeatures` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/requiredFeatures)\nSynonyms:\nsprocket/html/svg/attributes.required_features\nsprocket/html/svg/attributes required_features","url":"sprocket/html/svg/attributes.html#required_features"},{"doc":"sprocket/html/svg/attributes","title":"restart","content":"pub fn restart(value: String) -&gt; Attribute\n The [SVG `restart` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/restart)\nSynonyms:\nsprocket/html/svg/attributes.restart\nsprocket/html/svg/attributes restart","url":"sprocket/html/svg/attributes.html#restart"},{"doc":"sprocket/html/svg/attributes","title":"result","content":"pub fn result(value: String) -&gt; Attribute\n The [SVG `result` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/result)\nSynonyms:\nsprocket/html/svg/attributes.result\nsprocket/html/svg/attributes result","url":"sprocket/html/svg/attributes.html#result"},{"doc":"sprocket/html/svg/attributes","title":"rotate","content":"pub fn rotate(value: String) -&gt; Attribute\n The [SVG `rotate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rotate)\nSynonyms:\nsprocket/html/svg/attributes.rotate\nsprocket/html/svg/attributes rotate","url":"sprocket/html/svg/attributes.html#rotate"},{"doc":"sprocket/html/svg/attributes","title":"rx","content":"pub fn rx(value: String) -&gt; Attribute\n The [SVG `rx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rx)\nSynonyms:\nsprocket/html/svg/attributes.rx\nsprocket/html/svg/attributes rx","url":"sprocket/html/svg/attributes.html#rx"},{"doc":"sprocket/html/svg/attributes","title":"ry","content":"pub fn ry(value: String) -&gt; Attribute\n The [SVG `ry` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ry)\nSynonyms:\nsprocket/html/svg/attributes.ry\nsprocket/html/svg/attributes ry","url":"sprocket/html/svg/attributes.html#ry"},{"doc":"sprocket/html/svg/attributes","title":"scale","content":"pub fn scale(value: String) -&gt; Attribute\n The [SVG `scale` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/scale)\nSynonyms:\nsprocket/html/svg/attributes.scale\nsprocket/html/svg/attributes scale","url":"sprocket/html/svg/attributes.html#scale"},{"doc":"sprocket/html/svg/attributes","title":"seed","content":"pub fn seed(value: String) -&gt; Attribute\n The [SVG `seed` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/seed)\nSynonyms:\nsprocket/html/svg/attributes.seed\nsprocket/html/svg/attributes seed","url":"sprocket/html/svg/attributes.html#seed"},{"doc":"sprocket/html/svg/attributes","title":"shape_rendering","content":"pub fn shape_rendering(value: String) -&gt; Attribute\n The [SVG `shape-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/shape-rendering)\nSynonyms:\nsprocket/html/svg/attributes.shape_rendering\nsprocket/html/svg/attributes shape_rendering","url":"sprocket/html/svg/attributes.html#shape_rendering"},{"doc":"sprocket/html/svg/attributes","title":"slope","content":"pub fn slope(value: String) -&gt; Attribute\n The [SVG `slope` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/slope)\nSynonyms:\nsprocket/html/svg/attributes.slope\nsprocket/html/svg/attributes slope","url":"sprocket/html/svg/attributes.html#slope"},{"doc":"sprocket/html/svg/attributes","title":"spacing","content":"pub fn spacing(value: String) -&gt; Attribute\n The [SVG `spacing` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/spacing)\nSynonyms:\nsprocket/html/svg/attributes.spacing\nsprocket/html/svg/attributes spacing","url":"sprocket/html/svg/attributes.html#spacing"},{"doc":"sprocket/html/svg/attributes","title":"specular_constant","content":"pub fn specular_constant(value: String) -&gt; Attribute\n The [SVG `specularConstant` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/specularConstant)\nSynonyms:\nsprocket/html/svg/attributes.specular_constant\nsprocket/html/svg/attributes specular_constant","url":"sprocket/html/svg/attributes.html#specular_constant"},{"doc":"sprocket/html/svg/attributes","title":"specular_exponent","content":"pub fn specular_exponent(value: String) -&gt; Attribute\n The [SVG `specularExponent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/specularExponent)\nSynonyms:\nsprocket/html/svg/attributes.specular_exponent\nsprocket/html/svg/attributes specular_exponent","url":"sprocket/html/svg/attributes.html#specular_exponent"},{"doc":"sprocket/html/svg/attributes","title":"speed","content":"pub fn speed(value: String) -&gt; Attribute\n The [SVG `speed` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/speed)\nSynonyms:\nsprocket/html/svg/attributes.speed\nsprocket/html/svg/attributes speed","url":"sprocket/html/svg/attributes.html#speed"},{"doc":"sprocket/html/svg/attributes","title":"spread_method","content":"pub fn spread_method(value: String) -&gt; Attribute\n The [SVG `spreadMethod` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/spreadMethod)\nSynonyms:\nsprocket/html/svg/attributes.spread_method\nsprocket/html/svg/attributes spread_method","url":"sprocket/html/svg/attributes.html#spread_method"},{"doc":"sprocket/html/svg/attributes","title":"start_offset","content":"pub fn start_offset(value: String) -&gt; Attribute\n The [SVG `startOffset` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/startOffset)\nSynonyms:\nsprocket/html/svg/attributes.start_offset\nsprocket/html/svg/attributes start_offset","url":"sprocket/html/svg/attributes.html#start_offset"},{"doc":"sprocket/html/svg/attributes","title":"std_deviation","content":"pub fn std_deviation(value: String) -&gt; Attribute\n The [SVG `stdDeviation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stdDeviation)\nSynonyms:\nsprocket/html/svg/attributes.std_deviation\nsprocket/html/svg/attributes std_deviation","url":"sprocket/html/svg/attributes.html#std_deviation"},{"doc":"sprocket/html/svg/attributes","title":"stemh","content":"pub fn stemh(value: String) -&gt; Attribute\n The [SVG `stemh` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stemh)\nSynonyms:\nsprocket/html/svg/attributes.stemh\nsprocket/html/svg/attributes stemh","url":"sprocket/html/svg/attributes.html#stemh"},{"doc":"sprocket/html/svg/attributes","title":"stemv","content":"pub fn stemv(value: String) -&gt; Attribute\n The [SVG `stemv` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stemv)\nSynonyms:\nsprocket/html/svg/attributes.stemv\nsprocket/html/svg/attributes stemv","url":"sprocket/html/svg/attributes.html#stemv"},{"doc":"sprocket/html/svg/attributes","title":"stitch_tiles","content":"pub fn stitch_tiles(value: String) -&gt; Attribute\n The [SVG `stitchTiles` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stitchTiles)\nSynonyms:\nsprocket/html/svg/attributes.stitch_tiles\nsprocket/html/svg/attributes stitch_tiles","url":"sprocket/html/svg/attributes.html#stitch_tiles"},{"doc":"sprocket/html/svg/attributes","title":"stop_color","content":"pub fn stop_color(value: String) -&gt; Attribute\n The [SVG `stop-color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stop-color)\nSynonyms:\nsprocket/html/svg/attributes.stop_color\nsprocket/html/svg/attributes stop_color","url":"sprocket/html/svg/attributes.html#stop_color"},{"doc":"sprocket/html/svg/attributes","title":"stop_opacity","content":"pub fn stop_opacity(value: String) -&gt; Attribute\n The [SVG `stop-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stop-opacity)\nSynonyms:\nsprocket/html/svg/attributes.stop_opacity\nsprocket/html/svg/attributes stop_opacity","url":"sprocket/html/svg/attributes.html#stop_opacity"},{"doc":"sprocket/html/svg/attributes","title":"strikethrough_position","content":"pub fn strikethrough_position(value: String) -&gt; Attribute\n The [SVG `strikethrough-position` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/strikethrough-position)\nSynonyms:\nsprocket/html/svg/attributes.strikethrough_position\nsprocket/html/svg/attributes strikethrough_position","url":"sprocket/html/svg/attributes.html#strikethrough_position"},{"doc":"sprocket/html/svg/attributes","title":"strikethrough_thickness","content":"pub fn strikethrough_thickness(value: String) -&gt; Attribute\n The [SVG `strikethrough-thickness` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/strikethrough-thickness)\nSynonyms:\nsprocket/html/svg/attributes.strikethrough_thickness\nsprocket/html/svg/attributes strikethrough_thickness","url":"sprocket/html/svg/attributes.html#strikethrough_thickness"},{"doc":"sprocket/html/svg/attributes","title":"string","content":"pub fn string(value: String) -&gt; Attribute\n The [SVG `string` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/string)\nSynonyms:\nsprocket/html/svg/attributes.string\nsprocket/html/svg/attributes string","url":"sprocket/html/svg/attributes.html#string"},{"doc":"sprocket/html/svg/attributes","title":"stroke","content":"pub fn stroke(value: String) -&gt; Attribute\n The [SVG `stroke` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke)\nSynonyms:\nsprocket/html/svg/attributes.stroke\nsprocket/html/svg/attributes stroke","url":"sprocket/html/svg/attributes.html#stroke"},{"doc":"sprocket/html/svg/attributes","title":"stroke_dasharray","content":"pub fn stroke_dasharray(value: String) -&gt; Attribute\n The [SVG `stroke-dasharray` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-dasharray)\nSynonyms:\nsprocket/html/svg/attributes.stroke_dasharray\nsprocket/html/svg/attributes stroke_dasharray","url":"sprocket/html/svg/attributes.html#stroke_dasharray"},{"doc":"sprocket/html/svg/attributes","title":"stroke_dashoffset","content":"pub fn stroke_dashoffset(value: String) -&gt; Attribute\n The [SVG `stroke-dashoffset` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-dashoffset)\nSynonyms:\nsprocket/html/svg/attributes.stroke_dashoffset\nsprocket/html/svg/attributes stroke_dashoffset","url":"sprocket/html/svg/attributes.html#stroke_dashoffset"},{"doc":"sprocket/html/svg/attributes","title":"stroke_linecap","content":"pub fn stroke_linecap(value: String) -&gt; Attribute\n The [SVG `stroke-linecap` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-linecap)\nSynonyms:\nsprocket/html/svg/attributes.stroke_linecap\nsprocket/html/svg/attributes stroke_linecap","url":"sprocket/html/svg/attributes.html#stroke_linecap"},{"doc":"sprocket/html/svg/attributes","title":"stroke_linejoin","content":"pub fn stroke_linejoin(value: String) -&gt; Attribute\n The [SVG `stroke-linejoin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-linejoin)\nSynonyms:\nsprocket/html/svg/attributes.stroke_linejoin\nsprocket/html/svg/attributes stroke_linejoin","url":"sprocket/html/svg/attributes.html#stroke_linejoin"},{"doc":"sprocket/html/svg/attributes","title":"stroke_miterlimit","content":"pub fn stroke_miterlimit(value: String) -&gt; Attribute\n The [SVG `stroke-miterlimit` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-miterlimit)\nSynonyms:\nsprocket/html/svg/attributes.stroke_miterlimit\nsprocket/html/svg/attributes stroke_miterlimit","url":"sprocket/html/svg/attributes.html#stroke_miterlimit"},{"doc":"sprocket/html/svg/attributes","title":"stroke_opacity","content":"pub fn stroke_opacity(value: String) -&gt; Attribute\n The [SVG `stroke-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-opacity)\nSynonyms:\nsprocket/html/svg/attributes.stroke_opacity\nsprocket/html/svg/attributes stroke_opacity","url":"sprocket/html/svg/attributes.html#stroke_opacity"},{"doc":"sprocket/html/svg/attributes","title":"stroke_width","content":"pub fn stroke_width(value: String) -&gt; Attribute\n The [SVG `stroke-width` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-width)\nSynonyms:\nsprocket/html/svg/attributes.stroke_width\nsprocket/html/svg/attributes stroke_width","url":"sprocket/html/svg/attributes.html#stroke_width"},{"doc":"sprocket/html/svg/attributes","title":"style","content":"pub fn style(value: String) -&gt; Attribute\n The [SVG `style` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/style)\nSynonyms:\nsprocket/html/svg/attributes.style\nsprocket/html/svg/attributes style","url":"sprocket/html/svg/attributes.html#style"},{"doc":"sprocket/html/svg/attributes","title":"surface_scale","content":"pub fn surface_scale(value: String) -&gt; Attribute\n The [SVG `surfaceScale` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/surfaceScale)\nSynonyms:\nsprocket/html/svg/attributes.surface_scale\nsprocket/html/svg/attributes surface_scale","url":"sprocket/html/svg/attributes.html#surface_scale"},{"doc":"sprocket/html/svg/attributes","title":"system_language","content":"pub fn system_language(value: String) -&gt; Attribute\n The [SVG `systemLanguage` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/systemLanguage)\nSynonyms:\nsprocket/html/svg/attributes.system_language\nsprocket/html/svg/attributes system_language","url":"sprocket/html/svg/attributes.html#system_language"},{"doc":"sprocket/html/svg/attributes","title":"tabindex","content":"pub fn tabindex(value: String) -&gt; Attribute\n The [SVG `tabindex` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/tabindex)\nSynonyms:\nsprocket/html/svg/attributes.tabindex\nsprocket/html/svg/attributes tabindex","url":"sprocket/html/svg/attributes.html#tabindex"},{"doc":"sprocket/html/svg/attributes","title":"table_values","content":"pub fn table_values(value: String) -&gt; Attribute\n The [SVG `tableValues` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/tableValues)\nSynonyms:\nsprocket/html/svg/attributes.table_values\nsprocket/html/svg/attributes table_values","url":"sprocket/html/svg/attributes.html#table_values"},{"doc":"sprocket/html/svg/attributes","title":"target","content":"pub fn target(value: String) -&gt; Attribute\n The [SVG `target` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/target)\nSynonyms:\nsprocket/html/svg/attributes.target\nsprocket/html/svg/attributes target","url":"sprocket/html/svg/attributes.html#target"},{"doc":"sprocket/html/svg/attributes","title":"target_x","content":"pub fn target_x(value: String) -&gt; Attribute\n The [SVG `targetX` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/targetX)\nSynonyms:\nsprocket/html/svg/attributes.target_x\nsprocket/html/svg/attributes target_x","url":"sprocket/html/svg/attributes.html#target_x"},{"doc":"sprocket/html/svg/attributes","title":"target_y","content":"pub fn target_y(value: String) -&gt; Attribute\n The [SVG `targetY` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/targetY)\nSynonyms:\nsprocket/html/svg/attributes.target_y\nsprocket/html/svg/attributes target_y","url":"sprocket/html/svg/attributes.html#target_y"},{"doc":"sprocket/html/svg/attributes","title":"text_anchor","content":"pub fn text_anchor(value: String) -&gt; Attribute\n The [SVG `text-anchor` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/text-anchor)\nSynonyms:\nsprocket/html/svg/attributes.text_anchor\nsprocket/html/svg/attributes text_anchor","url":"sprocket/html/svg/attributes.html#text_anchor"},{"doc":"sprocket/html/svg/attributes","title":"text_decoration","content":"pub fn text_decoration(value: String) -&gt; Attribute\n The [SVG `text-decoration` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/text-decoration)\nSynonyms:\nsprocket/html/svg/attributes.text_decoration\nsprocket/html/svg/attributes text_decoration","url":"sprocket/html/svg/attributes.html#text_decoration"},{"doc":"sprocket/html/svg/attributes","title":"text_length","content":"pub fn text_length(value: String) -&gt; Attribute\n The [SVG `textLength` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/textLength)\nSynonyms:\nsprocket/html/svg/attributes.text_length\nsprocket/html/svg/attributes text_length","url":"sprocket/html/svg/attributes.html#text_length"},{"doc":"sprocket/html/svg/attributes","title":"text_rendering","content":"pub fn text_rendering(value: String) -&gt; Attribute\n The [SVG `text-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/text-rendering)\nSynonyms:\nsprocket/html/svg/attributes.text_rendering\nsprocket/html/svg/attributes text_rendering","url":"sprocket/html/svg/attributes.html#text_rendering"},{"doc":"sprocket/html/svg/attributes","title":"to","content":"pub fn to(value: String) -&gt; Attribute\n The [SVG `to` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/to)\nSynonyms:\nsprocket/html/svg/attributes.to\nsprocket/html/svg/attributes to","url":"sprocket/html/svg/attributes.html#to"},{"doc":"sprocket/html/svg/attributes","title":"transform","content":"pub fn transform(value: String) -&gt; Attribute\n The [SVG `transform` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/transform)\nSynonyms:\nsprocket/html/svg/attributes.transform\nsprocket/html/svg/attributes transform","url":"sprocket/html/svg/attributes.html#transform"},{"doc":"sprocket/html/svg/attributes","title":"transform_origin","content":"pub fn transform_origin(value: String) -&gt; Attribute\n The [SVG `transform-origin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/transform-origin)\nSynonyms:\nsprocket/html/svg/attributes.transform_origin\nsprocket/html/svg/attributes transform_origin","url":"sprocket/html/svg/attributes.html#transform_origin"},{"doc":"sprocket/html/svg/attributes","title":"type_","content":"pub fn type_(value: String) -&gt; Attribute\n The [SVG `type` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/type)\nSynonyms:\nsprocket/html/svg/attributes.type_\nsprocket/html/svg/attributes type_","url":"sprocket/html/svg/attributes.html#type_"},{"doc":"sprocket/html/svg/attributes","title":"u1","content":"pub fn u1(value: String) -&gt; Attribute\n The [SVG `u1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/u1)\nSynonyms:\nsprocket/html/svg/attributes.u1\nsprocket/html/svg/attributes u1","url":"sprocket/html/svg/attributes.html#u1"},{"doc":"sprocket/html/svg/attributes","title":"u2","content":"pub fn u2(value: String) -&gt; Attribute\n The [SVG `u2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/u2)\nSynonyms:\nsprocket/html/svg/attributes.u2\nsprocket/html/svg/attributes u2","url":"sprocket/html/svg/attributes.html#u2"},{"doc":"sprocket/html/svg/attributes","title":"underline_position","content":"pub fn underline_position(value: String) -&gt; Attribute\n The [SVG `underline-position` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/underline-position)\nSynonyms:\nsprocket/html/svg/attributes.underline_position\nsprocket/html/svg/attributes underline_position","url":"sprocket/html/svg/attributes.html#underline_position"},{"doc":"sprocket/html/svg/attributes","title":"underline_thickness","content":"pub fn underline_thickness(value: String) -&gt; Attribute\n The [SVG `underline-thickness` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/underline-thickness)\nSynonyms:\nsprocket/html/svg/attributes.underline_thickness\nsprocket/html/svg/attributes underline_thickness","url":"sprocket/html/svg/attributes.html#underline_thickness"},{"doc":"sprocket/html/svg/attributes","title":"unicode","content":"pub fn unicode(value: String) -&gt; Attribute\n The [SVG `unicode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/unicode)\nSynonyms:\nsprocket/html/svg/attributes.unicode\nsprocket/html/svg/attributes unicode","url":"sprocket/html/svg/attributes.html#unicode"},{"doc":"sprocket/html/svg/attributes","title":"unicode_bidi","content":"pub fn unicode_bidi(value: String) -&gt; Attribute\n The [SVG `unicode-bidi` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/unicode-bidi)\nSynonyms:\nsprocket/html/svg/attributes.unicode_bidi\nsprocket/html/svg/attributes unicode_bidi","url":"sprocket/html/svg/attributes.html#unicode_bidi"},{"doc":"sprocket/html/svg/attributes","title":"unicode_range","content":"pub fn unicode_range(value: String) -&gt; Attribute\n The [SVG `unicode-range` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/unicode-range)\nSynonyms:\nsprocket/html/svg/attributes.unicode_range\nsprocket/html/svg/attributes unicode_range","url":"sprocket/html/svg/attributes.html#unicode_range"},{"doc":"sprocket/html/svg/attributes","title":"units_per_em","content":"pub fn units_per_em(value: String) -&gt; Attribute\n The [SVG `units-per-em` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/units-per-em)\nSynonyms:\nsprocket/html/svg/attributes.units_per_em\nsprocket/html/svg/attributes units_per_em","url":"sprocket/html/svg/attributes.html#units_per_em"},{"doc":"sprocket/html/svg/attributes","title":"v_alphabetic","content":"pub fn v_alphabetic(value: String) -&gt; Attribute\n The [SVG `v-alphabetic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-alphabetic)\nSynonyms:\nsprocket/html/svg/attributes.v_alphabetic\nsprocket/html/svg/attributes v_alphabetic","url":"sprocket/html/svg/attributes.html#v_alphabetic"},{"doc":"sprocket/html/svg/attributes","title":"v_hanging","content":"pub fn v_hanging(value: String) -&gt; Attribute\n The [SVG `v-hanging` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-hanging)\nSynonyms:\nsprocket/html/svg/attributes.v_hanging\nsprocket/html/svg/attributes v_hanging","url":"sprocket/html/svg/attributes.html#v_hanging"},{"doc":"sprocket/html/svg/attributes","title":"v_ideographic","content":"pub fn v_ideographic(value: String) -&gt; Attribute\n The [SVG `v-ideographic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-ideographic)\nSynonyms:\nsprocket/html/svg/attributes.v_ideographic\nsprocket/html/svg/attributes v_ideographic","url":"sprocket/html/svg/attributes.html#v_ideographic"},{"doc":"sprocket/html/svg/attributes","title":"v_mathematical","content":"pub fn v_mathematical(value: String) -&gt; Attribute\n The [SVG `v-mathematical` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-mathematical)\nSynonyms:\nsprocket/html/svg/attributes.v_mathematical\nsprocket/html/svg/attributes v_mathematical","url":"sprocket/html/svg/attributes.html#v_mathematical"},{"doc":"sprocket/html/svg/attributes","title":"values","content":"pub fn values(value: String) -&gt; Attribute\n The [SVG `values` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/values)\nSynonyms:\nsprocket/html/svg/attributes.values\nsprocket/html/svg/attributes values","url":"sprocket/html/svg/attributes.html#values"},{"doc":"sprocket/html/svg/attributes","title":"vector_effect","content":"pub fn vector_effect(value: String) -&gt; Attribute\n The [SVG `vector-effect` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vector-effect)\nSynonyms:\nsprocket/html/svg/attributes.vector_effect\nsprocket/html/svg/attributes vector_effect","url":"sprocket/html/svg/attributes.html#vector_effect"},{"doc":"sprocket/html/svg/attributes","title":"version","content":"pub fn version(value: String) -&gt; Attribute\n The [SVG `version` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/version)\nSynonyms:\nsprocket/html/svg/attributes.version\nsprocket/html/svg/attributes version","url":"sprocket/html/svg/attributes.html#version"},{"doc":"sprocket/html/svg/attributes","title":"vert_adv_y","content":"pub fn vert_adv_y(value: String) -&gt; Attribute\n The [SVG `vert-adv-y` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vert-adv-y)\nSynonyms:\nsprocket/html/svg/attributes.vert_adv_y\nsprocket/html/svg/attributes vert_adv_y","url":"sprocket/html/svg/attributes.html#vert_adv_y"},{"doc":"sprocket/html/svg/attributes","title":"vert_origin_x","content":"pub fn vert_origin_x(value: String) -&gt; Attribute\n The [SVG `vert-origin-x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vert-origin-x)\nSynonyms:\nsprocket/html/svg/attributes.vert_origin_x\nsprocket/html/svg/attributes vert_origin_x","url":"sprocket/html/svg/attributes.html#vert_origin_x"},{"doc":"sprocket/html/svg/attributes","title":"vert_origin_y","content":"pub fn vert_origin_y(value: String) -&gt; Attribute\n The [SVG `vert-origin-y` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vert-origin-y)\nSynonyms:\nsprocket/html/svg/attributes.vert_origin_y\nsprocket/html/svg/attributes vert_origin_y","url":"sprocket/html/svg/attributes.html#vert_origin_y"},{"doc":"sprocket/html/svg/attributes","title":"view_box","content":"pub fn view_box(value: String) -&gt; Attribute\n The [SVG `viewBox` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/viewBox)\nSynonyms:\nsprocket/html/svg/attributes.view_box\nsprocket/html/svg/attributes view_box","url":"sprocket/html/svg/attributes.html#view_box"},{"doc":"sprocket/html/svg/attributes","title":"view_target","content":"pub fn view_target(value: String) -&gt; Attribute\n The [SVG `viewTarget` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/viewTarget)\nSynonyms:\nsprocket/html/svg/attributes.view_target\nsprocket/html/svg/attributes view_target","url":"sprocket/html/svg/attributes.html#view_target"},{"doc":"sprocket/html/svg/attributes","title":"visibility","content":"pub fn visibility(value: String) -&gt; Attribute\n The [SVG `visibility` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/visibility)\nSynonyms:\nsprocket/html/svg/attributes.visibility\nsprocket/html/svg/attributes visibility","url":"sprocket/html/svg/attributes.html#visibility"},{"doc":"sprocket/html/svg/attributes","title":"width","content":"pub fn width(value: String) -&gt; Attribute\n The [SVG `width` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/width)\nSynonyms:\nsprocket/html/svg/attributes.width\nsprocket/html/svg/attributes width","url":"sprocket/html/svg/attributes.html#width"},{"doc":"sprocket/html/svg/attributes","title":"widths","content":"pub fn widths(value: String) -&gt; Attribute\n The [SVG `widths` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/widths)\nSynonyms:\nsprocket/html/svg/attributes.widths\nsprocket/html/svg/attributes widths","url":"sprocket/html/svg/attributes.html#widths"},{"doc":"sprocket/html/svg/attributes","title":"word_spacing","content":"pub fn word_spacing(value: String) -&gt; Attribute\n The [SVG `word-spacing` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/word-spacing)\nSynonyms:\nsprocket/html/svg/attributes.word_spacing\nsprocket/html/svg/attributes word_spacing","url":"sprocket/html/svg/attributes.html#word_spacing"},{"doc":"sprocket/html/svg/attributes","title":"writing_mode","content":"pub fn writing_mode(value: String) -&gt; Attribute\n The [SVG `writing-mode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/writing-mode)\nSynonyms:\nsprocket/html/svg/attributes.writing_mode\nsprocket/html/svg/attributes writing_mode","url":"sprocket/html/svg/attributes.html#writing_mode"},{"doc":"sprocket/html/svg/attributes","title":"x","content":"pub fn x(value: String) -&gt; Attribute\n The [SVG `x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x)\nSynonyms:\nsprocket/html/svg/attributes.x\nsprocket/html/svg/attributes x","url":"sprocket/html/svg/attributes.html#x"},{"doc":"sprocket/html/svg/attributes","title":"x1","content":"pub fn x1(value: String) -&gt; Attribute\n The [SVG `x1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x1)\nSynonyms:\nsprocket/html/svg/attributes.x1\nsprocket/html/svg/attributes x1","url":"sprocket/html/svg/attributes.html#x1"},{"doc":"sprocket/html/svg/attributes","title":"x2","content":"pub fn x2(value: String) -&gt; Attribute\n The [SVG `x2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x2)\nSynonyms:\nsprocket/html/svg/attributes.x2\nsprocket/html/svg/attributes x2","url":"sprocket/html/svg/attributes.html#x2"},{"doc":"sprocket/html/svg/attributes","title":"x_channel_selector","content":"pub fn x_channel_selector(value: String) -&gt; Attribute\n The [SVG `xChannelSelector` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xChannelSelector)\nSynonyms:\nsprocket/html/svg/attributes.x_channel_selector\nsprocket/html/svg/attributes x_channel_selector","url":"sprocket/html/svg/attributes.html#x_channel_selector"},{"doc":"sprocket/html/svg/attributes","title":"x_height","content":"pub fn x_height(value: String) -&gt; Attribute\n The [SVG `x-height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x-height)\nSynonyms:\nsprocket/html/svg/attributes.x_height\nsprocket/html/svg/attributes x_height","url":"sprocket/html/svg/attributes.html#x_height"},{"doc":"sprocket/html/svg/attributes","title":"xlink_actuate","content":"pub fn xlink_actuate(value: String) -&gt; Attribute\n The [SVG `xlink:actuate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:actuate)\nSynonyms:\nsprocket/html/svg/attributes.xlink_actuate\nsprocket/html/svg/attributes xlink_actuate","url":"sprocket/html/svg/attributes.html#xlink_actuate"},{"doc":"sprocket/html/svg/attributes","title":"xlink_arcrole","content":"pub fn xlink_arcrole(value: String) -&gt; Attribute\n The [SVG `xlink:arcrole` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:arcrole)\nSynonyms:\nsprocket/html/svg/attributes.xlink_arcrole\nsprocket/html/svg/attributes xlink_arcrole","url":"sprocket/html/svg/attributes.html#xlink_arcrole"},{"doc":"sprocket/html/svg/attributes","title":"xlink_href","content":"pub fn xlink_href(value: String) -&gt; Attribute\n The [SVG `xlink:href` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:href)\nSynonyms:\nsprocket/html/svg/attributes.xlink_href\nsprocket/html/svg/attributes xlink_href","url":"sprocket/html/svg/attributes.html#xlink_href"},{"doc":"sprocket/html/svg/attributes","title":"xlink_role","content":"pub fn xlink_role(value: String) -&gt; Attribute\n The [SVG `xlink:role` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:role)\nSynonyms:\nsprocket/html/svg/attributes.xlink_role\nsprocket/html/svg/attributes xlink_role","url":"sprocket/html/svg/attributes.html#xlink_role"},{"doc":"sprocket/html/svg/attributes","title":"xlink_show","content":"pub fn xlink_show(value: String) -&gt; Attribute\n The [SVG `xlink:show` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:show)\nSynonyms:\nsprocket/html/svg/attributes.xlink_show\nsprocket/html/svg/attributes xlink_show","url":"sprocket/html/svg/attributes.html#xlink_show"},{"doc":"sprocket/html/svg/attributes","title":"xlink_title","content":"pub fn xlink_title(value: String) -&gt; Attribute\n The [SVG `xlink:title` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:title)\nSynonyms:\nsprocket/html/svg/attributes.xlink_title\nsprocket/html/svg/attributes xlink_title","url":"sprocket/html/svg/attributes.html#xlink_title"},{"doc":"sprocket/html/svg/attributes","title":"xlink_type","content":"pub fn xlink_type(value: String) -&gt; Attribute\n The [SVG `xlink:type` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:type)\nSynonyms:\nsprocket/html/svg/attributes.xlink_type\nsprocket/html/svg/attributes xlink_type","url":"sprocket/html/svg/attributes.html#xlink_type"},{"doc":"sprocket/html/svg/attributes","title":"xml_base","content":"pub fn xml_base(value: String) -&gt; Attribute\n The [SVG `xml:base` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xml:base)\nSynonyms:\nsprocket/html/svg/attributes.xml_base\nsprocket/html/svg/attributes xml_base","url":"sprocket/html/svg/attributes.html#xml_base"},{"doc":"sprocket/html/svg/attributes","title":"xml_lang","content":"pub fn xml_lang(value: String) -&gt; Attribute\n The [SVG `xml:lang` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xml:lang)\nSynonyms:\nsprocket/html/svg/attributes.xml_lang\nsprocket/html/svg/attributes xml_lang","url":"sprocket/html/svg/attributes.html#xml_lang"},{"doc":"sprocket/html/svg/attributes","title":"xml_space","content":"pub fn xml_space(value: String) -&gt; Attribute\n The [SVG `xml:space` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xml:space)\nSynonyms:\nsprocket/html/svg/attributes.xml_space\nsprocket/html/svg/attributes xml_space","url":"sprocket/html/svg/attributes.html#xml_space"},{"doc":"sprocket/html/svg/attributes","title":"y","content":"pub fn y(value: String) -&gt; Attribute\n The [SVG `y` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/y)\nSynonyms:\nsprocket/html/svg/attributes.y\nsprocket/html/svg/attributes y","url":"sprocket/html/svg/attributes.html#y"},{"doc":"sprocket/html/svg/attributes","title":"y1","content":"pub fn y1(value: String) -&gt; Attribute\n The [SVG `y1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/y1)\nSynonyms:\nsprocket/html/svg/attributes.y1\nsprocket/html/svg/attributes y1","url":"sprocket/html/svg/attributes.html#y1"},{"doc":"sprocket/html/svg/attributes","title":"y2","content":"pub fn y2(value: String) -&gt; Attribute\n The [SVG `y2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/y2)\nSynonyms:\nsprocket/html/svg/attributes.y2\nsprocket/html/svg/attributes y2","url":"sprocket/html/svg/attributes.html#y2"},{"doc":"sprocket/html/svg/attributes","title":"y_channel_selector","content":"pub fn y_channel_selector(value: String) -&gt; Attribute\n The [SVG `yChannelSelector` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/yChannelSelector)\nSynonyms:\nsprocket/html/svg/attributes.y_channel_selector\nsprocket/html/svg/attributes y_channel_selector","url":"sprocket/html/svg/attributes.html#y_channel_selector"},{"doc":"sprocket/html/svg/attributes","title":"z","content":"pub fn z(value: String) -&gt; Attribute\n The [SVG `z` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/z)\nSynonyms:\nsprocket/html/svg/attributes.z\nsprocket/html/svg/attributes z","url":"sprocket/html/svg/attributes.html#z"},{"doc":"sprocket/html/svg/attributes","title":"zoom_and_pan","content":"pub fn zoom_and_pan(value: String) -&gt; Attribute\n The [SVG `zoomAndPan` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/zoomAndPan)\nSynonyms:\nsprocket/html/svg/attributes.zoom_and_pan\nsprocket/html/svg/attributes zoom_and_pan","url":"sprocket/html/svg/attributes.html#zoom_and_pan"},{"doc":"sprocket/html/svg/attributes","title":"sprocket/html/svg/attributes","content":"","url":"sprocket/html/svg/attributes.html"},{"doc":"sprocket/component","title":"component","content":"pub fn component(\n  c: fn(Context, a) -&gt; #(Context, Element),\n  props: a,\n) -&gt; Element\n\nSynonyms:\nsprocket/component.component\nsprocket/component component","url":"sprocket/component.html#component"},{"doc":"sprocket/component","title":"render","content":"pub fn render(\n  ctx: Context,\n  elements: Element,\n) -&gt; #(Context, Element)\n\nSynonyms:\nsprocket/component.render\nsprocket/component render","url":"sprocket/component.html#render"},{"doc":"sprocket/component","title":"sprocket/component","content":"","url":"sprocket/component.html"},{"doc":"sprocket","title":"CSRFValidator","content":"pub type CSRFValidator =\n  fn(String) -&gt; Result(Nil, Nil)\n\n\nSynonyms:\nsprocket.CSRFValidator\nsprocket CSRFValidator","url":"sprocket.html#CSRFValidator"},{"doc":"sprocket","title":"Response","content":"pub type Response {\n  Joined(spkt: Sprocket)\n  Empty\n}\n\nJoined(spkt: Sprocket)\n\n\nEmpty\n\n\nSynonyms:\nsprocket.Response\nsprocket Response","url":"sprocket.html#Response"},{"doc":"sprocket","title":"Sprocket","content":"pub type Sprocket {\n  Sprocket(\n    runtime: Option(Runtime),\n    view: Element,\n    ws_send: WSSend,\n    csrf_validator: CSRFValidator,\n    opts: Option(SprocketOpts),\n  )\n}\n\nSprocket(\n  runtime: Option(Runtime),\n  view: Element,\n  ws_send: WSSend,\n  csrf_validator: CSRFValidator,\n  opts: Option(SprocketOpts),\n)\n\n\nSynonyms:\nsprocket.Sprocket\nsprocket Sprocket","url":"sprocket.html#Sprocket"},{"doc":"sprocket","title":"SprocketOpts","content":"pub type SprocketOpts {\n  SprocketOpts(debug: Bool)\n}\n\nSprocketOpts(debug: Bool)\n\n\nSynonyms:\nsprocket.SprocketOpts\nsprocket SprocketOpts","url":"sprocket.html#SprocketOpts"},{"doc":"sprocket","title":"WSSend","content":"pub type WSSend =\n  fn(String) -&gt; Result(Nil, Nil)\n\n\nSynonyms:\nsprocket.WSSend\nsprocket WSSend","url":"sprocket.html#WSSend"},{"doc":"sprocket","title":"cleanup","content":"pub fn cleanup(spkt: Sprocket) -&gt; Option(Nil)\n Cleanup a sprocket. This function is called when a websocket is closed. It will find\n the sprocket that is associated with the websocket and stop it.\n\n Its important to call this function when the websocket connection is terminated.\nSynonyms:\nsprocket.cleanup\nsprocket cleanup","url":"sprocket.html#cleanup"},{"doc":"sprocket","title":"handle_ws","content":"pub fn handle_ws(\n  spkt: Sprocket,\n  msg: String,\n) -&gt; Result(Response, String)\n Handle a message from the websocket. This function is called when a message is received\n from the websocket. It will find the sprocket that is associated with the websocket and\n pass the message to the sprocket. The sprocket will then handle the message and send\n a response back to the websocket.\nSynonyms:\nsprocket.handle_ws\nsprocket handle_ws","url":"sprocket.html#handle_ws"},{"doc":"sprocket","title":"new","content":"pub fn new(\n  view: Element,\n  ws_send: fn(String) -&gt; Result(Nil, Nil),\n  csrf_validator: fn(String) -&gt; Result(Nil, Nil),\n  opts: Option(SprocketOpts),\n) -&gt; Sprocket\n\nSynonyms:\nsprocket.new\nsprocket new","url":"sprocket.html#new"},{"doc":"sprocket","title":"render","content":"pub fn render(el: Element, r: Renderer(a)) -&gt; a\n\nSynonyms:\nsprocket.render\nsprocket render","url":"sprocket.html#render"},{"doc":"sprocket","title":"sprocket","content":"","url":"sprocket.html"}]);